#[repr(i32)]pub enum ProtoErrorCode {
UnknownError = 1,
UnsupportedMessage = 2,
InvalidRequest = 3,
TimeoutError = 5,
EntityNotFound = 6,
CantRouteRequest = 7,
FrameTooLong = 8,
MarketClosed = 9,
ConcurrentModification = 10,
BlockedPayloadType = 11,
}Expand description
COMMON error codes 1 - 99
Variants
UnknownError = 1
Generic error.
UnsupportedMessage = 2
Message is not supported. Wrong message.
InvalidRequest = 3
Generic error. Usually used when input value is not correct.
TimeoutError = 5
Deal execution is reached timeout and rejected.
EntityNotFound = 6
Generic error for requests by id.
CantRouteRequest = 7
Connection to Server is lost or not supported.
FrameTooLong = 8
Message is too large.
MarketClosed = 9
Market is closed.
ConcurrentModification = 10
Order is blocked (e.g. under execution) and change cannot be applied.
BlockedPayloadType = 11
Message is blocked by server or rate limit is reached.
Implementations
Sourceimpl ProtoErrorCode
impl ProtoErrorCode
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.