#[repr(i32)]pub enum ProtoOaAccessRights {
FullAccess = 0,
CloseOnly = 1,
NoTrading = 2,
NoLogin = 3,
}Expand description
- Enum for specifying access right for a trader.
Variants
FullAccess = 0
Enable all trading.
CloseOnly = 1
Only closing trading request are enabled.
NoTrading = 2
View only access.
NoLogin = 3
No access.
Implementations
Sourceimpl ProtoOaAccessRights
impl ProtoOaAccessRights
Sourcepub fn from_i32(value: i32) -> Option<ProtoOaAccessRights>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<ProtoOaAccessRights>
Converts an i32 to a ProtoOaAccessRights, or None if value is not a valid variant.
Sourceimpl ProtoOaAccessRights
impl ProtoOaAccessRights
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.