#[repr(i32)]pub enum ProtoOaAccountType {
Hedged = 0,
Netted = 1,
SpreadBetting = 2,
}Expand description
- Enum for specifying type of an account.
Variants
Hedged = 0
Allows multiple positions on a trading account for a symbol.
Netted = 1
Only one position per symbol is allowed on a trading account.
SpreadBetting = 2
Spread betting type account.
Implementations
Sourceimpl ProtoOaAccountType
impl ProtoOaAccountType
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.