#[repr(i32)]pub enum ProtoOaClientPermissionScope {
ScopeView = 0,
ScopeTrade = 1,
}Expand description
- Open API application permission in regards to token ENUM.
Variants
ScopeView = 0
Allows to use only view commends. Trade is prohibited.
ScopeTrade = 1
Allows to use all commands.
Implementations
Sourceimpl ProtoOaClientPermissionScope
impl ProtoOaClientPermissionScope
Sourcepub fn is_valid(value: i32) -> bool
pub fn is_valid(value: i32) -> bool
Returns true if value is a variant of ProtoOaClientPermissionScope.
Sourcepub fn from_i32(value: i32) -> Option<ProtoOaClientPermissionScope>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<ProtoOaClientPermissionScope>
Converts an i32 to a ProtoOaClientPermissionScope, or None if value is not a valid variant.
Sourceimpl ProtoOaClientPermissionScope
impl ProtoOaClientPermissionScope
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.