ProtoOaCommissionType

Enum ProtoOaCommissionType 

#[repr(i32)]
pub enum ProtoOaCommissionType { UsdPerMillionUsd = 1, UsdPerLot = 2, PercentageOfValue = 3, QuoteCcyPerLot = 4, }
  • Enum for specifying type of trading commission.

Variants



UsdPerMillionUsd = 1

USD per million USD volume - usually used for FX. Example: 50 USD for 1 mil USD of trading volume.



UsdPerLot = 2

USD per 1 lot - usually used for CFDs and futures for commodities, and indices. Example: 15 USD for 1 contract.



PercentageOfValue = 3

Percentage of trading volume - usually used for Equities. Example: 0.005% of notional trading volume. Multiplied by 100,000.



QuoteCcyPerLot = 4

Quote ccy of Symbol per 1 lot - will be used for CFDs and futures for commodities, and indices. Example: 15 EUR for 1 contract of DAX.

Implementations

Source

impl ProtoOaCommissionType

pub fn is_valid(value: i32) -> bool

Returns true if value is a variant of ProtoOaCommissionType.

pub fn from_i32(value: i32) -> Option<ProtoOaCommissionType>

👎Deprecated: Use the TryFrom<i32> implementation instead

Converts an i32 to a ProtoOaCommissionType, or None if value is not a valid variant.

Source

impl ProtoOaCommissionType

pub fn as_str_name(&self) -> &'static str

String value of the enum field names used in the ProtoBuf definition.

The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.

pub fn from_str_name(value: &str) -> Option<Self>

Creates an enum from field names used in the ProtoBuf definition.