#[repr(i32)]pub enum ProtoOaExecutionType {
OrderAccepted = 2,
OrderFilled = 3,
OrderReplaced = 4,
OrderCancelled = 5,
OrderExpired = 6,
OrderRejected = 7,
OrderCancelRejected = 8,
Swap = 9,
DepositWithdraw = 10,
OrderPartialFill = 11,
BonusDepositWithdraw = 12,
}Expand description
- Execution event type ENUM.
Variants
OrderAccepted = 2
Order passed validation.
OrderFilled = 3
Order filled.
OrderReplaced = 4
Pending order is changed with a new one.
OrderCancelled = 5
Order cancelled.
OrderExpired = 6
Order with GTD time in force is expired.
OrderRejected = 7
Order is rejected due to validations.
OrderCancelRejected = 8
Cancel order request is rejected.
Swap = 9
Type related to SWAP execution events.
DepositWithdraw = 10
Type related to event of deposit or withdrawal cash flow operation.
OrderPartialFill = 11
Order is partially filled.
BonusDepositWithdraw = 12
Type related to event of bonus deposit or bonus withdrawal.
Implementations
Sourceimpl ProtoOaExecutionType
impl ProtoOaExecutionType
Sourcepub fn is_valid(value: i32) -> bool
pub fn is_valid(value: i32) -> bool
Returns true if value is a variant of ProtoOaExecutionType.
Sourcepub fn from_i32(value: i32) -> Option<ProtoOaExecutionType>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<ProtoOaExecutionType>
Converts an i32 to a ProtoOaExecutionType, or None if value is not a valid variant.
Sourceimpl ProtoOaExecutionType
impl ProtoOaExecutionType
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.