#[repr(i32)]pub enum ProtoOaNotificationType {
MarginLevelThreshold1 = 61,
MarginLevelThreshold2 = 62,
MarginLevelThreshold3 = 63,
}Expand description
- Type of notification, currently only 3 instances of marginCall are supported.
Variants
MarginLevelThreshold1 = 61
one of three margin calls, they are all similar.
MarginLevelThreshold2 = 62
one of three margin calls, they are all similar.
MarginLevelThreshold3 = 63
one of three margin calls, they are all similar.
Implementations
Sourceimpl ProtoOaNotificationType
impl ProtoOaNotificationType
Sourcepub fn is_valid(value: i32) -> bool
pub fn is_valid(value: i32) -> bool
Returns true if value is a variant of ProtoOaNotificationType.
Sourcepub fn from_i32(value: i32) -> Option<ProtoOaNotificationType>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<ProtoOaNotificationType>
Converts an i32 to a ProtoOaNotificationType, or None if value is not a valid variant.
Sourceimpl ProtoOaNotificationType
impl ProtoOaNotificationType
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.