#[repr(i32)]pub enum ProtoOaOrderStatus {
OrderStatusAccepted = 1,
OrderStatusFilled = 2,
OrderStatusRejected = 3,
OrderStatusExpired = 4,
OrderStatusCancelled = 5,
}Expand description
- Order status ENUM.
Variants
OrderStatusAccepted = 1
Order request validated and accepted for execution.
OrderStatusFilled = 2
Order is fully filled.
OrderStatusRejected = 3
Order is rejected due to validation.
OrderStatusExpired = 4
Order expired. Might be valid for orders with partially filled volume that were expired on LP.
OrderStatusCancelled = 5
Order is cancelled. Might be valid for orders with partially filled volume that were cancelled by LP.
Implementations
Sourceimpl ProtoOaOrderStatus
impl ProtoOaOrderStatus
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.