#[repr(i32)]pub enum ProtoOaOrderTriggerMethod {
Trade = 1,
Opposite = 2,
DoubleTrade = 3,
DoubleOpposite = 4,
}Expand description
- Stop Order and Stop Loss triggering method ENUM.
Variants
Trade = 1
Stop Order: buy is triggered by ask, sell by bid; Stop Loss Order: for buy position is triggered by bid and for sell position by ask.
Opposite = 2
Stop Order: buy is triggered by bid, sell by ask; Stop Loss Order: for buy position is triggered by ask and for sell position by bid.
DoubleTrade = 3
The same as TRADE, but trigger is checked after the second consecutive tick.
DoubleOpposite = 4
The same as OPPOSITE, but trigger is checked after the second consecutive tick.
Implementations
Sourceimpl ProtoOaOrderTriggerMethod
impl ProtoOaOrderTriggerMethod
Sourcepub fn is_valid(value: i32) -> bool
pub fn is_valid(value: i32) -> bool
Returns true if value is a variant of ProtoOaOrderTriggerMethod.
Sourcepub fn from_i32(value: i32) -> Option<ProtoOaOrderTriggerMethod>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<ProtoOaOrderTriggerMethod>
Converts an i32 to a ProtoOaOrderTriggerMethod, or None if value is not a valid variant.
Sourceimpl ProtoOaOrderTriggerMethod
impl ProtoOaOrderTriggerMethod
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.