#[repr(i32)]pub enum ProtoOaPayloadType {
Show 89 variants
ProtoOaApplicationAuthReq = 2_100,
ProtoOaApplicationAuthRes = 2_101,
ProtoOaAccountAuthReq = 2_102,
ProtoOaAccountAuthRes = 2_103,
ProtoOaVersionReq = 2_104,
ProtoOaVersionRes = 2_105,
ProtoOaNewOrderReq = 2_106,
ProtoOaTrailingSlChangedEvent = 2_107,
ProtoOaCancelOrderReq = 2_108,
ProtoOaAmendOrderReq = 2_109,
ProtoOaAmendPositionSltpReq = 2_110,
ProtoOaClosePositionReq = 2_111,
ProtoOaAssetListReq = 2_112,
ProtoOaAssetListRes = 2_113,
ProtoOaSymbolsListReq = 2_114,
ProtoOaSymbolsListRes = 2_115,
ProtoOaSymbolByIdReq = 2_116,
ProtoOaSymbolByIdRes = 2_117,
ProtoOaSymbolsForConversionReq = 2_118,
ProtoOaSymbolsForConversionRes = 2_119,
ProtoOaSymbolChangedEvent = 2_120,
ProtoOaTraderReq = 2_121,
ProtoOaTraderRes = 2_122,
ProtoOaTraderUpdateEvent = 2_123,
ProtoOaReconcileReq = 2_124,
ProtoOaReconcileRes = 2_125,
ProtoOaExecutionEvent = 2_126,
ProtoOaSubscribeSpotsReq = 2_127,
ProtoOaSubscribeSpotsRes = 2_128,
ProtoOaUnsubscribeSpotsReq = 2_129,
ProtoOaUnsubscribeSpotsRes = 2_130,
ProtoOaSpotEvent = 2_131,
ProtoOaOrderErrorEvent = 2_132,
ProtoOaDealListReq = 2_133,
ProtoOaDealListRes = 2_134,
ProtoOaSubscribeLiveTrendbarReq = 2_135,
ProtoOaUnsubscribeLiveTrendbarReq = 2_136,
ProtoOaGetTrendbarsReq = 2_137,
ProtoOaGetTrendbarsRes = 2_138,
ProtoOaExpectedMarginReq = 2_139,
ProtoOaExpectedMarginRes = 2_140,
ProtoOaMarginChangedEvent = 2_141,
ProtoOaErrorRes = 2_142,
ProtoOaCashFlowHistoryListReq = 2_143,
ProtoOaCashFlowHistoryListRes = 2_144,
ProtoOaGetTickdataReq = 2_145,
ProtoOaGetTickdataRes = 2_146,
ProtoOaAccountsTokenInvalidatedEvent = 2_147,
ProtoOaClientDisconnectEvent = 2_148,
ProtoOaGetAccountsByAccessTokenReq = 2_149,
ProtoOaGetAccountsByAccessTokenRes = 2_150,
ProtoOaGetCtidProfileByTokenReq = 2_151,
ProtoOaGetCtidProfileByTokenRes = 2_152,
ProtoOaAssetClassListReq = 2_153,
ProtoOaAssetClassListRes = 2_154,
ProtoOaDepthEvent = 2_155,
ProtoOaSubscribeDepthQuotesReq = 2_156,
ProtoOaSubscribeDepthQuotesRes = 2_157,
ProtoOaUnsubscribeDepthQuotesReq = 2_158,
ProtoOaUnsubscribeDepthQuotesRes = 2_159,
ProtoOaSymbolCategoryReq = 2_160,
ProtoOaSymbolCategoryRes = 2_161,
ProtoOaAccountLogoutReq = 2_162,
ProtoOaAccountLogoutRes = 2_163,
ProtoOaAccountDisconnectEvent = 2_164,
ProtoOaSubscribeLiveTrendbarRes = 2_165,
ProtoOaUnsubscribeLiveTrendbarRes = 2_166,
ProtoOaMarginCallListReq = 2_167,
ProtoOaMarginCallListRes = 2_168,
ProtoOaMarginCallUpdateReq = 2_169,
ProtoOaMarginCallUpdateRes = 2_170,
ProtoOaMarginCallUpdateEvent = 2_171,
ProtoOaMarginCallTriggerEvent = 2_172,
ProtoOaRefreshTokenReq = 2_173,
ProtoOaRefreshTokenRes = 2_174,
ProtoOaOrderListReq = 2_175,
ProtoOaOrderListRes = 2_176,
ProtoOaGetDynamicLeverageReq = 2_177,
ProtoOaGetDynamicLeverageRes = 2_178,
ProtoOaDealListByPositionIdReq = 2_179,
ProtoOaDealListByPositionIdRes = 2_180,
ProtoOaOrderDetailsReq = 2_181,
ProtoOaOrderDetailsRes = 2_182,
ProtoOaOrderListByPositionIdReq = 2_183,
ProtoOaOrderListByPositionIdRes = 2_184,
ProtoOaDealOffsetListReq = 2_185,
ProtoOaDealOffsetListRes = 2_186,
ProtoOaGetPositionUnrealizedPnlReq = 2_187,
ProtoOaGetPositionUnrealizedPnlRes = 2_188,
}Variants
ProtoOaApplicationAuthReq = 2_100
ProtoOaApplicationAuthRes = 2_101
ProtoOaAccountAuthReq = 2_102
ProtoOaAccountAuthRes = 2_103
ProtoOaVersionReq = 2_104
ProtoOaVersionRes = 2_105
ProtoOaNewOrderReq = 2_106
ProtoOaTrailingSlChangedEvent = 2_107
ProtoOaCancelOrderReq = 2_108
ProtoOaAmendOrderReq = 2_109
ProtoOaAmendPositionSltpReq = 2_110
ProtoOaClosePositionReq = 2_111
ProtoOaAssetListReq = 2_112
ProtoOaAssetListRes = 2_113
ProtoOaSymbolsListReq = 2_114
ProtoOaSymbolsListRes = 2_115
ProtoOaSymbolByIdReq = 2_116
ProtoOaSymbolByIdRes = 2_117
ProtoOaSymbolsForConversionReq = 2_118
ProtoOaSymbolsForConversionRes = 2_119
ProtoOaSymbolChangedEvent = 2_120
ProtoOaTraderReq = 2_121
ProtoOaTraderRes = 2_122
ProtoOaTraderUpdateEvent = 2_123
ProtoOaReconcileReq = 2_124
ProtoOaReconcileRes = 2_125
ProtoOaExecutionEvent = 2_126
ProtoOaSubscribeSpotsReq = 2_127
ProtoOaSubscribeSpotsRes = 2_128
ProtoOaUnsubscribeSpotsReq = 2_129
ProtoOaUnsubscribeSpotsRes = 2_130
ProtoOaSpotEvent = 2_131
ProtoOaOrderErrorEvent = 2_132
ProtoOaDealListReq = 2_133
ProtoOaDealListRes = 2_134
ProtoOaSubscribeLiveTrendbarReq = 2_135
ProtoOaUnsubscribeLiveTrendbarReq = 2_136
ProtoOaGetTrendbarsReq = 2_137
ProtoOaGetTrendbarsRes = 2_138
ProtoOaExpectedMarginReq = 2_139
ProtoOaExpectedMarginRes = 2_140
ProtoOaMarginChangedEvent = 2_141
ProtoOaErrorRes = 2_142
ProtoOaCashFlowHistoryListReq = 2_143
ProtoOaCashFlowHistoryListRes = 2_144
ProtoOaGetTickdataReq = 2_145
ProtoOaGetTickdataRes = 2_146
ProtoOaAccountsTokenInvalidatedEvent = 2_147
ProtoOaClientDisconnectEvent = 2_148
ProtoOaGetAccountsByAccessTokenReq = 2_149
ProtoOaGetAccountsByAccessTokenRes = 2_150
ProtoOaGetCtidProfileByTokenReq = 2_151
ProtoOaGetCtidProfileByTokenRes = 2_152
ProtoOaAssetClassListReq = 2_153
ProtoOaAssetClassListRes = 2_154
ProtoOaDepthEvent = 2_155
ProtoOaSubscribeDepthQuotesReq = 2_156
ProtoOaSubscribeDepthQuotesRes = 2_157
ProtoOaUnsubscribeDepthQuotesReq = 2_158
ProtoOaUnsubscribeDepthQuotesRes = 2_159
ProtoOaSymbolCategoryReq = 2_160
ProtoOaSymbolCategoryRes = 2_161
ProtoOaAccountLogoutReq = 2_162
ProtoOaAccountLogoutRes = 2_163
ProtoOaAccountDisconnectEvent = 2_164
ProtoOaSubscribeLiveTrendbarRes = 2_165
ProtoOaUnsubscribeLiveTrendbarRes = 2_166
ProtoOaMarginCallListReq = 2_167
ProtoOaMarginCallListRes = 2_168
ProtoOaMarginCallUpdateReq = 2_169
ProtoOaMarginCallUpdateRes = 2_170
ProtoOaMarginCallUpdateEvent = 2_171
ProtoOaMarginCallTriggerEvent = 2_172
ProtoOaRefreshTokenReq = 2_173
ProtoOaRefreshTokenRes = 2_174
ProtoOaOrderListReq = 2_175
ProtoOaOrderListRes = 2_176
ProtoOaGetDynamicLeverageReq = 2_177
ProtoOaGetDynamicLeverageRes = 2_178
ProtoOaDealListByPositionIdReq = 2_179
ProtoOaDealListByPositionIdRes = 2_180
ProtoOaOrderDetailsReq = 2_181
ProtoOaOrderDetailsRes = 2_182
ProtoOaOrderListByPositionIdReq = 2_183
ProtoOaOrderListByPositionIdRes = 2_184
ProtoOaDealOffsetListReq = 2_185
ProtoOaDealOffsetListRes = 2_186
ProtoOaGetPositionUnrealizedPnlReq = 2_187
ProtoOaGetPositionUnrealizedPnlRes = 2_188
Implementations
Sourceimpl ProtoOaPayloadType
impl ProtoOaPayloadType
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.