#[repr(i32)]pub enum ProtoOaStopOutStrategy {
MostMarginUsedFirst = 0,
MostLosingFirst = 1,
}Expand description
The strategy for choosing which Position to close during a Stop Out
Variants
MostMarginUsedFirst = 0
A Stop Out strategy that closes a Position with the largest Used Margin
MostLosingFirst = 1
A Stop Out strategy that closes a Position with the least PnL
Implementations
Sourceimpl ProtoOaStopOutStrategy
impl ProtoOaStopOutStrategy
Sourcepub fn is_valid(value: i32) -> bool
pub fn is_valid(value: i32) -> bool
Returns true if value is a variant of ProtoOaStopOutStrategy.
Sourcepub fn from_i32(value: i32) -> Option<ProtoOaStopOutStrategy>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<ProtoOaStopOutStrategy>
Converts an i32 to a ProtoOaStopOutStrategy, or None if value is not a valid variant.
Sourceimpl ProtoOaStopOutStrategy
impl ProtoOaStopOutStrategy
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.