#[repr(i32)]pub enum ProtoOaTotalMarginCalculationType {
Max = 0,
Sum = 1,
Net = 2,
}Expand description
- Enum for specifying margin calculation type for an account.
Variants
Implementations
Sourceimpl ProtoOaTotalMarginCalculationType
impl ProtoOaTotalMarginCalculationType
Sourcepub fn is_valid(value: i32) -> bool
pub fn is_valid(value: i32) -> bool
Returns true if value is a variant of ProtoOaTotalMarginCalculationType.
Sourcepub fn from_i32(value: i32) -> Option<ProtoOaTotalMarginCalculationType>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<ProtoOaTotalMarginCalculationType>
Converts an i32 to a ProtoOaTotalMarginCalculationType, or None if value is not a valid variant.
Sourceimpl ProtoOaTotalMarginCalculationType
impl ProtoOaTotalMarginCalculationType
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.