#[repr(i32)]pub enum ProtoOaTradingMode {
Enabled = 0,
DisabledWithoutPendingsExecution = 1,
DisabledWithPendingsExecution = 2,
CloseOnlyMode = 3,
}Expand description
- Enum for specifying symbol trading mode.
Variants
Enabled = 0
DisabledWithoutPendingsExecution = 1
DisabledWithPendingsExecution = 2
CloseOnlyMode = 3
Implementations
Sourceimpl ProtoOaTradingMode
impl ProtoOaTradingMode
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.