#[repr(i32)]pub enum ProtoOaTrendbarPeriod {
Show 14 variants
M1 = 1,
M2 = 2,
M3 = 3,
M4 = 4,
M5 = 5,
M10 = 6,
M15 = 7,
M30 = 8,
H1 = 9,
H4 = 10,
H12 = 11,
D1 = 12,
W1 = 13,
Mn1 = 14,
}Expand description
- Trendbar period ENUM.
Variants
M1 = 1
M2 = 2
M3 = 3
M4 = 4
M5 = 5
M10 = 6
M15 = 7
M30 = 8
H1 = 9
H4 = 10
H12 = 11
D1 = 12
W1 = 13
Mn1 = 14
Implementations
Sourceimpl ProtoOaTrendbarPeriod
impl ProtoOaTrendbarPeriod
Sourcepub fn is_valid(value: i32) -> bool
pub fn is_valid(value: i32) -> bool
Returns true if value is a variant of ProtoOaTrendbarPeriod.
Sourcepub fn from_i32(value: i32) -> Option<ProtoOaTrendbarPeriod>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<ProtoOaTrendbarPeriod>
Converts an i32 to a ProtoOaTrendbarPeriod, or None if value is not a valid variant.
Sourceimpl ProtoOaTrendbarPeriod
impl ProtoOaTrendbarPeriod
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.