pub struct ProtoHeartbeatEvent {
pub payload_type: Option<i32>,
}Expand description
- Event that is sent from Open API proxy and can be used as criteria that connection is healthy when no other messages are sent by cTrader platform. Open API client can send this message when he needs to keep the connection open for a period without other messages longer than 30 seconds.
Fields
payload_type: Option<i32>Implementations
Sourceimpl ProtoHeartbeatEvent
impl ProtoHeartbeatEvent
Sourcepub fn payload_type(&self) -> ProtoPayloadType
pub fn payload_type(&self) -> ProtoPayloadType
Returns the enum value of payload_type, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_payload_type(&mut self, value: ProtoPayloadType)
pub fn set_payload_type(&mut self, value: ProtoPayloadType)
Sets payload_type to the provided enum value.