pub struct ProtoMessage {
pub payload_type: u32,
pub payload: Option<Vec<u8>>,
pub client_msg_id: Option<String>,
}Expand description
- Base message that is used for all messages that are sent to/from Open API proxy of cTrader platform.
Fields
payload_type: u32Contains id of ProtoPayloadType or other custom PayloadTypes (e.g. ProtoOAPayloadType).
payload: Option<Vec<u8>>Serialized protobuf message that corresponds to payloadType.
client_msg_id: Option<String>Request message id, assigned by the client that will be returned in the response.
Implementations
Sourceimpl ProtoMessage
impl ProtoMessage