pub struct ProtoOaAccountAuthReq {
pub payload_type: Option<i32>,
pub ctid_trader_account_id: i64,
pub access_token: String,
}Expand description
- Request for authorizing of the trading account session. Requires established authorized connection with the client application using ProtoOAApplicationAuthReq.
Fields
payload_type: Option<i32>ctid_trader_account_id: i64The unique identifier of the trader’s account in cTrader platform.
access_token: StringThe Access Token issued for providing access to the Trader’s Account.
Implementations
Sourceimpl ProtoOaAccountAuthReq
impl ProtoOaAccountAuthReq
Sourcepub fn payload_type(&self) -> ProtoOaPayloadType
pub fn payload_type(&self) -> ProtoOaPayloadType
Returns the enum value of payload_type, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_payload_type(&mut self, value: ProtoOaPayloadType)
pub fn set_payload_type(&mut self, value: ProtoOaPayloadType)
Sets payload_type to the provided enum value.