pub struct ProtoOaAccountLogoutRes {
pub payload_type: Option<i32>,
pub ctid_trader_account_id: i64,
}Expand description
- Response to the ProtoOAAccountLogoutReq request. Actual logout of trading account will be completed on ProtoOAAccountDisconnectEvent.
Fields
payload_type: Option<i32>ctid_trader_account_id: i64The unique identifier of the trader’s account in cTrader platform.
Implementations
Sourceimpl ProtoOaAccountLogoutRes
impl ProtoOaAccountLogoutRes
Sourcepub fn payload_type(&self) -> ProtoOaPayloadType
pub fn payload_type(&self) -> ProtoOaPayloadType
Returns the enum value of payload_type, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_payload_type(&mut self, value: ProtoOaPayloadType)
pub fn set_payload_type(&mut self, value: ProtoOaPayloadType)
Sets payload_type to the provided enum value.