pub struct ProtoOaAccountsTokenInvalidatedEvent {
pub payload_type: Option<i32>,
pub ctid_trader_account_ids: Vec<i64>,
pub reason: Option<String>,
}Expand description
- Event that is sent when a session to a specific trader’s account is terminated by the server but the existing connections with the other trader’s accounts are maintained. Reasons to trigger: account was deleted, cTID was deleted, token was refreshed, token was revoked.
Fields
payload_type: Option<i32>ctid_trader_account_ids: Vec<i64>The unique identifier of the trader’s account in cTrader platform.
reason: Option<String>The disconnection reason explained. For example: Access Token is expired or recalled.
Implementations
Sourceimpl ProtoOaAccountsTokenInvalidatedEvent
impl ProtoOaAccountsTokenInvalidatedEvent
Sourcepub fn payload_type(&self) -> ProtoOaPayloadType
pub fn payload_type(&self) -> ProtoOaPayloadType
Returns the enum value of payload_type, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_payload_type(&mut self, value: ProtoOaPayloadType)
pub fn set_payload_type(&mut self, value: ProtoOaPayloadType)
Sets payload_type to the provided enum value.