pub struct ProtoOaAmendOrderReq {Show 15 fields
pub payload_type: Option<i32>,
pub ctid_trader_account_id: i64,
pub order_id: i64,
pub volume: Option<i64>,
pub limit_price: Option<f64>,
pub stop_price: Option<f64>,
pub expiration_timestamp: Option<i64>,
pub stop_loss: Option<f64>,
pub take_profit: Option<f64>,
pub slippage_in_points: Option<i32>,
pub relative_stop_loss: Option<i64>,
pub relative_take_profit: Option<i64>,
pub guaranteed_stop_loss: Option<bool>,
pub trailing_stop_loss: Option<bool>,
pub stop_trigger_method: Option<i32>,
}Expand description
- Request for amending the existing pending order. Allowed only if the Access Token has “trade” permissions for the trading account.
Fields
payload_type: Option<i32>ctid_trader_account_id: i64Unique identifier of the trader’s account. Used to match responses to trader’s accounts.
order_id: i64The unique ID of the order.
volume: Option<i64>Volume, represented in 0.01 of a unit (e.g. 1000 in protocol means 10.00 units).
limit_price: Option<f64>The Limit Price, can be specified for the LIMIT order only.
stop_price: Option<f64>The Stop Price, can be specified for the STOP and the STOP_LIMIT orders.
expiration_timestamp: Option<i64>The Unix timestamp in milliseconds of Order expiration. Should be set for the Good Till Date orders.
stop_loss: Option<f64>The absolute Stop Loss price (e.g. 1.23456). Not supported for MARKET orders.
take_profit: Option<f64>The absolute Take Profit price (e.g. 1.23456). Not supported for MARKET orders.
slippage_in_points: Option<i32>Slippage distance for the MARKET_RANGE and the STOP_LIMIT orders.
relative_stop_loss: Option<i64>The relative Stop Loss can be specified instead of the absolute one. Specified in 1/100000 of a unit of price. (e.g. 123000 in protocol means 1.23, 53423782 means 534.23782) For BUY stopLoss = entryPrice - relativeStopLoss, for SELL stopLoss = entryPrice + relativeStopLoss.
relative_take_profit: Option<i64>The relative Take Profit can be specified instead of the absolute one. Specified in 1/100000 of a unit of price. (e.g. 123000 in protocol means 1.23, 53423782 means 534.23782) For BUY takeProfit = entryPrice + relativeTakeProfit, for SELL takeProfit = entryPrice - relativeTakeProfit.
guaranteed_stop_loss: Option<bool>If TRUE then the Stop Loss is guaranteed. Available for the French Risk or the Guaranteed Stop Loss Accounts.
trailing_stop_loss: Option<bool>If TRUE then the Trailing Stop Loss is applied.
stop_trigger_method: Option<i32>Trigger method for the STOP or the STOP_LIMIT pending order.
Implementations
Sourceimpl ProtoOaAmendOrderReq
impl ProtoOaAmendOrderReq
Sourcepub fn payload_type(&self) -> ProtoOaPayloadType
pub fn payload_type(&self) -> ProtoOaPayloadType
Returns the enum value of payload_type, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_payload_type(&mut self, value: ProtoOaPayloadType)
pub fn set_payload_type(&mut self, value: ProtoOaPayloadType)
Sets payload_type to the provided enum value.
Sourcepub fn volume(&self) -> i64
pub fn volume(&self) -> i64
Returns the value of volume, or the default value if volume is unset.
Sourcepub fn limit_price(&self) -> f64
pub fn limit_price(&self) -> f64
Returns the value of limit_price, or the default value if limit_price is unset.
Sourcepub fn stop_price(&self) -> f64
pub fn stop_price(&self) -> f64
Returns the value of stop_price, or the default value if stop_price is unset.
Sourcepub fn expiration_timestamp(&self) -> i64
pub fn expiration_timestamp(&self) -> i64
Returns the value of expiration_timestamp, or the default value if expiration_timestamp is unset.
Sourcepub fn stop_loss(&self) -> f64
pub fn stop_loss(&self) -> f64
Returns the value of stop_loss, or the default value if stop_loss is unset.
Sourcepub fn take_profit(&self) -> f64
pub fn take_profit(&self) -> f64
Returns the value of take_profit, or the default value if take_profit is unset.
Sourcepub fn slippage_in_points(&self) -> i32
pub fn slippage_in_points(&self) -> i32
Returns the value of slippage_in_points, or the default value if slippage_in_points is unset.
Sourcepub fn relative_stop_loss(&self) -> i64
pub fn relative_stop_loss(&self) -> i64
Returns the value of relative_stop_loss, or the default value if relative_stop_loss is unset.
Sourcepub fn relative_take_profit(&self) -> i64
pub fn relative_take_profit(&self) -> i64
Returns the value of relative_take_profit, or the default value if relative_take_profit is unset.
Sourcepub fn guaranteed_stop_loss(&self) -> bool
pub fn guaranteed_stop_loss(&self) -> bool
Returns the value of guaranteed_stop_loss, or the default value if guaranteed_stop_loss is unset.
Sourcepub fn trailing_stop_loss(&self) -> bool
pub fn trailing_stop_loss(&self) -> bool
Returns the value of trailing_stop_loss, or the default value if trailing_stop_loss is unset.
Sourcepub fn stop_trigger_method(&self) -> ProtoOaOrderTriggerMethod
pub fn stop_trigger_method(&self) -> ProtoOaOrderTriggerMethod
Returns the enum value of stop_trigger_method, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_stop_trigger_method(&mut self, value: ProtoOaOrderTriggerMethod)
pub fn set_stop_trigger_method(&mut self, value: ProtoOaOrderTriggerMethod)
Sets stop_trigger_method to the provided enum value.