pub struct ProtoOaApplicationAuthReq {
pub payload_type: Option<i32>,
pub client_id: String,
pub client_secret: String,
}Expand description
- Request for the authorizing an application to work with the cTrader platform Proxies.
Fields
payload_type: Option<i32>client_id: StringThe unique Client ID provided during the registration.
client_secret: StringThe unique Client Secret provided during the registration.
Implementations
Sourceimpl ProtoOaApplicationAuthReq
impl ProtoOaApplicationAuthReq
Sourcepub fn payload_type(&self) -> ProtoOaPayloadType
pub fn payload_type(&self) -> ProtoOaPayloadType
Returns the enum value of payload_type, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_payload_type(&mut self, value: ProtoOaPayloadType)
pub fn set_payload_type(&mut self, value: ProtoOaPayloadType)
Sets payload_type to the provided enum value.