pub struct ProtoOaAssetListReq {
pub payload_type: Option<i32>,
pub ctid_trader_account_id: i64,
}Expand description
- Request for the list of assets available for a trader’s account.
Fields
payload_type: Option<i32>ctid_trader_account_id: i64Unique identifier of the trader’s account. Used to match responses to trader’s accounts.
Implementations
Sourceimpl ProtoOaAssetListReq
impl ProtoOaAssetListReq
Sourcepub fn payload_type(&self) -> ProtoOaPayloadType
pub fn payload_type(&self) -> ProtoOaPayloadType
Returns the enum value of payload_type, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_payload_type(&mut self, value: ProtoOaPayloadType)
pub fn set_payload_type(&mut self, value: ProtoOaPayloadType)
Sets payload_type to the provided enum value.