pub struct ProtoOaBonusDepositWithdraw {
pub operation_type: i32,
pub bonus_history_id: i64,
pub manager_bonus: i64,
pub manager_delta: i64,
pub ib_bonus: i64,
pub ib_delta: i64,
pub change_bonus_timestamp: i64,
pub external_note: Option<String>,
pub introducing_broker_id: Option<i64>,
pub money_digits: Option<u32>,
}Expand description
- Bonus deposit/withdrawal entity.
Fields
operation_type: i32Type of the operation. Deposit/Withdrawal.
bonus_history_id: i64The unique ID of the bonus deposit/withdrawal operation.
manager_bonus: i64Total amount of broker’s bonus after the operation.
manager_delta: i64Amount of bonus deposited/withdrew by manager.
ib_bonus: i64Total amount of introducing broker’s bonus after the operation.
ib_delta: i64Amount of bonus deposited/withdrew by introducing broker.
change_bonus_timestamp: i64The Unix time in milliseconds when the bonus operation was executed.
external_note: Option<String>Note added to operation. Visible to the trader.
introducing_broker_id: Option<i64>ID of introducing broker who deposited/withdrew bonus.
money_digits: Option<u32>Specifies the exponent of the monetary values. E.g. moneyDigits = 8 must be interpret as business value multiplied by 10^8, then real balance would be 10053099944 / 10^8 = 100.53099944. Affects managerBonus, managerDelta, ibBonus, ibDelta.
Implementations
Sourceimpl ProtoOaBonusDepositWithdraw
impl ProtoOaBonusDepositWithdraw
Sourcepub fn operation_type(&self) -> ProtoOaChangeBonusType
pub fn operation_type(&self) -> ProtoOaChangeBonusType
Returns the enum value of operation_type, or the default if the field is set to an invalid enum value.
Sourcepub fn set_operation_type(&mut self, value: ProtoOaChangeBonusType)
pub fn set_operation_type(&mut self, value: ProtoOaChangeBonusType)
Sets operation_type to the provided enum value.
Sourcepub fn external_note(&self) -> &str
pub fn external_note(&self) -> &str
Returns the value of external_note, or the default value if external_note is unset.
Sourcepub fn introducing_broker_id(&self) -> i64
pub fn introducing_broker_id(&self) -> i64
Returns the value of introducing_broker_id, or the default value if introducing_broker_id is unset.
Sourcepub fn money_digits(&self) -> u32
pub fn money_digits(&self) -> u32
Returns the value of money_digits, or the default value if money_digits is unset.