pub struct ProtoOaCashFlowHistoryListReq {
pub payload_type: Option<i32>,
pub ctid_trader_account_id: i64,
pub from_timestamp: i64,
pub to_timestamp: i64,
}Expand description
- Request for getting Trader’s historical data of deposits and withdrawals.
Fields
payload_type: Option<i32>ctid_trader_account_id: i64Unique identifier of the trader’s account. Used to match responses to trader’s accounts.
from_timestamp: i64The Unix time from which the search starts >=0 (1st Jan 1970). Validation: toTimestamp - fromTimestamp <= 604800000 (1 week).
to_timestamp: i64The Unix time where to stop searching <= 2147483646000 (19th Jan 2038).
Implementations
Sourceimpl ProtoOaCashFlowHistoryListReq
impl ProtoOaCashFlowHistoryListReq
Sourcepub fn payload_type(&self) -> ProtoOaPayloadType
pub fn payload_type(&self) -> ProtoOaPayloadType
Returns the enum value of payload_type, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_payload_type(&mut self, value: ProtoOaPayloadType)
pub fn set_payload_type(&mut self, value: ProtoOaPayloadType)
Sets payload_type to the provided enum value.