pub struct ProtoOaClientDisconnectEvent {
pub payload_type: Option<i32>,
pub reason: Option<String>,
}Expand description
- Event that is sent when the connection with the client application is cancelled by the server. All the sessions for the traders’ accounts will be terminated.
Fields
payload_type: Option<i32>reason: Option<String>The disconnection reason explained. For example: The application access was blocked by cTrader Administrator.
Implementations
Sourceimpl ProtoOaClientDisconnectEvent
impl ProtoOaClientDisconnectEvent
Sourcepub fn payload_type(&self) -> ProtoOaPayloadType
pub fn payload_type(&self) -> ProtoOaPayloadType
Returns the enum value of payload_type, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_payload_type(&mut self, value: ProtoOaPayloadType)
pub fn set_payload_type(&mut self, value: ProtoOaPayloadType)
Sets payload_type to the provided enum value.