pub struct ProtoOaClosePositionReq {
pub payload_type: Option<i32>,
pub ctid_trader_account_id: i64,
pub position_id: i64,
pub volume: i64,
}Expand description
- Request for closing or partially closing of an existing position. Allowed only if the accessToken has “trade” permissions for the trading account.
Fields
payload_type: Option<i32>ctid_trader_account_id: i64Unique identifier of the trader’s account. Used to match responses to trader’s accounts.
position_id: i64The unique ID of the position to close.
volume: i64Volume to close, represented in 0.01 of a unit (e.g. 1000 in protocol means 10.00 units).
Implementations
Sourceimpl ProtoOaClosePositionReq
impl ProtoOaClosePositionReq
Sourcepub fn payload_type(&self) -> ProtoOaPayloadType
pub fn payload_type(&self) -> ProtoOaPayloadType
Returns the enum value of payload_type, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_payload_type(&mut self, value: ProtoOaPayloadType)
pub fn set_payload_type(&mut self, value: ProtoOaPayloadType)
Sets payload_type to the provided enum value.