pub struct ProtoOaCtidTraderAccount {
pub ctid_trader_account_id: u64,
pub is_live: Option<bool>,
pub trader_login: Option<i64>,
pub last_closing_deal_timestamp: Option<i64>,
pub last_balance_update_timestamp: Option<i64>,
pub broker_title_short: Option<String>,
}Expand description
- Trader account entity.
Fields
ctid_trader_account_id: u64Unique identifier of the trader’s account. Used to match responses to trader’s accounts.cTrader platform. Different brokers might have different ids
is_live: Option<bool>If TRUE then the account is belong to Live environment and live host must be used to authorize it
trader_login: Option<i64>TraderLogin for a specific account. Value is displayed on Client App UI
last_closing_deal_timestamp: Option<i64>The Unix time in milliseconds of the last ProtoOAClosePositionDetail happened to this account.
last_balance_update_timestamp: Option<i64>The Unix time in milliseconds of the last ProtoOADepositWithdraw happened to this account.
broker_title_short: Option<String>The name of the broker to which the account belongs to. Shortened to be displayed in the UI.
Implementations
Sourceimpl ProtoOaCtidTraderAccount
impl ProtoOaCtidTraderAccount
Sourcepub fn is_live(&self) -> bool
pub fn is_live(&self) -> bool
Returns the value of is_live, or the default value if is_live is unset.
Sourcepub fn trader_login(&self) -> i64
pub fn trader_login(&self) -> i64
Returns the value of trader_login, or the default value if trader_login is unset.
Sourcepub fn last_closing_deal_timestamp(&self) -> i64
pub fn last_closing_deal_timestamp(&self) -> i64
Returns the value of last_closing_deal_timestamp, or the default value if last_closing_deal_timestamp is unset.
Sourcepub fn last_balance_update_timestamp(&self) -> i64
pub fn last_balance_update_timestamp(&self) -> i64
Returns the value of last_balance_update_timestamp, or the default value if last_balance_update_timestamp is unset.
Sourcepub fn broker_title_short(&self) -> &str
pub fn broker_title_short(&self) -> &str
Returns the value of broker_title_short, or the default value if broker_title_short is unset.