ProtoOaDealListByPositionIdRes

Struct ProtoOaDealListByPositionIdRes 

pub struct ProtoOaDealListByPositionIdRes {
    pub payload_type: Option<i32>,
    pub ctid_trader_account_id: i64,
    pub deal: Vec<ProtoOaDeal>,
    pub has_more: bool,
}
  • Response to the ProtoOADealListByPositionIdReq request.

Fields

payload_type: Option<i32>ctid_trader_account_id: i64

Unique identifier of the trader’s account. Used to match responses to trader’s accounts.

deal: Vec<ProtoOaDeal>

The list of deals.

has_more: bool

If TRUE then the number of records by filter is larger than chunkSize, the response contains the number of records that is equal to chunkSize.

Implementations

Source

impl ProtoOaDealListByPositionIdRes

pub fn payload_type(&self) -> ProtoOaPayloadType

Returns the enum value of payload_type, or the default if the field is unset or set to an invalid enum value.

pub fn set_payload_type(&mut self, value: ProtoOaPayloadType)

Sets payload_type to the provided enum value.