pub struct ProtoOaDealListReq {
pub payload_type: Option<i32>,
pub ctid_trader_account_id: i64,
pub from_timestamp: Option<i64>,
pub to_timestamp: Option<i64>,
pub max_rows: Option<i32>,
}Expand description
- Request for getting Trader’s deals historical data (execution details).
Fields
payload_type: Option<i32>ctid_trader_account_id: i64Unique identifier of the trader’s account. Used to match responses to trader’s accounts.
from_timestamp: Option<i64>The Unix time from which the search starts >=0 (1st Jan 1970).
to_timestamp: Option<i64>The Unix time where to stop searching <= 2147483646000 (19th Jan 2038).
max_rows: Option<i32>The maximum number of the deals to return.
Implementations
Sourceimpl ProtoOaDealListReq
impl ProtoOaDealListReq
Sourcepub fn payload_type(&self) -> ProtoOaPayloadType
pub fn payload_type(&self) -> ProtoOaPayloadType
Returns the enum value of payload_type, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_payload_type(&mut self, value: ProtoOaPayloadType)
pub fn set_payload_type(&mut self, value: ProtoOaPayloadType)
Sets payload_type to the provided enum value.
Sourcepub fn from_timestamp(&self) -> i64
pub fn from_timestamp(&self) -> i64
Returns the value of from_timestamp, or the default value if from_timestamp is unset.
Sourcepub fn to_timestamp(&self) -> i64
pub fn to_timestamp(&self) -> i64
Returns the value of to_timestamp, or the default value if to_timestamp is unset.