pub struct ProtoOaDealOffsetListReq {
pub payload_type: Option<i32>,
pub ctid_trader_account_id: i64,
pub deal_id: i64,
}Expand description
- Request for getting sets of Deals that were offset by a specific Deal and that are offsetting the Deal.
Fields
payload_type: Option<i32>ctid_trader_account_id: i64Unique identifier of the trader’s account. Used to match responses to trader’s accounts.
deal_id: i64The unique ID of the Deal.
Implementations
Sourceimpl ProtoOaDealOffsetListReq
impl ProtoOaDealOffsetListReq
Sourcepub fn payload_type(&self) -> ProtoOaPayloadType
pub fn payload_type(&self) -> ProtoOaPayloadType
Returns the enum value of payload_type, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_payload_type(&mut self, value: ProtoOaPayloadType)
pub fn set_payload_type(&mut self, value: ProtoOaPayloadType)
Sets payload_type to the provided enum value.