pub struct ProtoOaDepthEvent {
pub payload_type: Option<i32>,
pub ctid_trader_account_id: i64,
pub symbol_id: u64,
pub new_quotes: Vec<ProtoOaDepthQuote>,
pub deleted_quotes: Vec<u64>,
}Expand description
- Event that is sent when the structure of depth of market is changed. Requires subscription on the depth of markets for the symbol, see ProtoOASubscribeDepthQuotesReq.
Fields
payload_type: Option<i32>ctid_trader_account_id: i64Unique identifier of the trader’s account. Used to match responses to trader’s accounts.
symbol_id: u64Unique identifier of the Symbol in cTrader platform.
new_quotes: Vec<ProtoOaDepthQuote>The list of changes in the depth of market quotes.
deleted_quotes: Vec<u64>The list of quotes to delete.
Implementations
Sourceimpl ProtoOaDepthEvent
impl ProtoOaDepthEvent
Sourcepub fn payload_type(&self) -> ProtoOaPayloadType
pub fn payload_type(&self) -> ProtoOaPayloadType
Returns the enum value of payload_type, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_payload_type(&mut self, value: ProtoOaPayloadType)
pub fn set_payload_type(&mut self, value: ProtoOaPayloadType)
Sets payload_type to the provided enum value.