ProtoOaExecutionEvent

Struct ProtoOaExecutionEvent 

pub struct ProtoOaExecutionEvent {
    pub payload_type: Option<i32>,
    pub ctid_trader_account_id: i64,
    pub execution_type: i32,
    pub position: Option<ProtoOaPosition>,
    pub order: Option<ProtoOaOrder>,
    pub deal: Option<ProtoOaDeal>,
    pub bonus_deposit_withdraw: Option<ProtoOaBonusDepositWithdraw>,
    pub deposit_withdraw: Option<ProtoOaDepositWithdraw>,
    pub error_code: Option<String>,
    pub is_server_event: Option<bool>,
}
  • Event that is sent following the successful order acceptance or execution by the server. Acts as response to the ProtoOANewOrderReq, ProtoOACancelOrderReq, ProtoOAAmendOrderReq, ProtoOAAmendPositionSLTPReq, ProtoOAClosePositionReq requests. Also, the event is sent when a Deposit/Withdrawal took place.

Fields

payload_type: Option<i32>ctid_trader_account_id: i64

Unique identifier of the trader’s account. Used to match responses to trader’s accounts.

execution_type: i32

Type of the order operation. For example: ACCEPTED, FILLED, etc.

position: Option<ProtoOaPosition>

Reference to the position linked with the execution

order: Option<ProtoOaOrder>

Reference to the initial order.

deal: Option<ProtoOaDeal>

Reference to the deal (execution).

bonus_deposit_withdraw: Option<ProtoOaBonusDepositWithdraw>

Reference to the Bonus Deposit or Withdrawal operation.

deposit_withdraw: Option<ProtoOaDepositWithdraw>

Reference to the Deposit or Withdrawal operation.

error_code: Option<String>

The name of the ProtoErrorCode or the other custom ErrorCodes (e.g. ProtoCHErrorCode).

is_server_event: Option<bool>

If TRUE then the event generated by the server logic instead of the trader’s request. (e.g. stop-out).

Implementations

Source

impl ProtoOaExecutionEvent

pub fn payload_type(&self) -> ProtoOaPayloadType

Returns the enum value of payload_type, or the default if the field is unset or set to an invalid enum value.

pub fn set_payload_type(&mut self, value: ProtoOaPayloadType)

Sets payload_type to the provided enum value.

pub fn execution_type(&self) -> ProtoOaExecutionType

Returns the enum value of execution_type, or the default if the field is set to an invalid enum value.

pub fn set_execution_type(&mut self, value: ProtoOaExecutionType)

Sets execution_type to the provided enum value.

pub fn error_code(&self) -> &str

Returns the value of error_code, or the default value if error_code is unset.

pub fn is_server_event(&self) -> bool

Returns the value of is_server_event, or the default value if is_server_event is unset.