pub struct ProtoOaExpectedMarginReq {
pub payload_type: Option<i32>,
pub ctid_trader_account_id: i64,
pub symbol_id: i64,
pub volume: Vec<i64>,
}Expand description
- Request for getting the margin estimate according to leverage profiles. Can be used before sending a new order request. This doesn’t consider ACCORDING_TO_GSL margin calculation type, as this calculation is trivial: usedMargin = (VWAP price of the position - GSL price) * volume * Quote2Deposit.
Fields
payload_type: Option<i32>ctid_trader_account_id: i64Unique identifier of the trader’s account. Used to match responses to trader’s accounts.
symbol_id: i64Unique identifier of the Symbol in cTrader platform.
volume: Vec<i64>Volume represented in 0.01 of a unit (e.g. 1000 in protocol means 10.00 units).
Implementations
Sourceimpl ProtoOaExpectedMarginReq
impl ProtoOaExpectedMarginReq
Sourcepub fn payload_type(&self) -> ProtoOaPayloadType
pub fn payload_type(&self) -> ProtoOaPayloadType
Returns the enum value of payload_type, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_payload_type(&mut self, value: ProtoOaPayloadType)
pub fn set_payload_type(&mut self, value: ProtoOaPayloadType)
Sets payload_type to the provided enum value.