pub struct ProtoOaGetAccountListByAccessTokenReq {
pub payload_type: Option<i32>,
pub access_token: String,
}Expand description
- Request for getting the list of granted trader’s account for the access token.
Fields
payload_type: Option<i32>access_token: StringThe Access Token issued for providing access to the Trader’s Account.
Implementations
Sourceimpl ProtoOaGetAccountListByAccessTokenReq
impl ProtoOaGetAccountListByAccessTokenReq
Sourcepub fn payload_type(&self) -> ProtoOaPayloadType
pub fn payload_type(&self) -> ProtoOaPayloadType
Returns the enum value of payload_type, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_payload_type(&mut self, value: ProtoOaPayloadType)
pub fn set_payload_type(&mut self, value: ProtoOaPayloadType)
Sets payload_type to the provided enum value.