pub struct ProtoOaGetAccountListByAccessTokenRes {
pub payload_type: Option<i32>,
pub access_token: String,
pub permission_scope: Option<i32>,
pub ctid_trader_account: Vec<ProtoOaCtidTraderAccount>,
}Expand description
- Response to the ProtoOAGetAccountListByAccessTokenReq request.
Fields
payload_type: Option<i32>access_token: StringThe Access Token issued for providing access to the Trader’s Account.
permission_scope: Option<i32>SCOPE_VIEW, SCOPE_TRADE.
ctid_trader_account: Vec<ProtoOaCtidTraderAccount>The list of the accounts.
Implementations
Sourceimpl ProtoOaGetAccountListByAccessTokenRes
impl ProtoOaGetAccountListByAccessTokenRes
Sourcepub fn payload_type(&self) -> ProtoOaPayloadType
pub fn payload_type(&self) -> ProtoOaPayloadType
Returns the enum value of payload_type, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_payload_type(&mut self, value: ProtoOaPayloadType)
pub fn set_payload_type(&mut self, value: ProtoOaPayloadType)
Sets payload_type to the provided enum value.
Sourcepub fn permission_scope(&self) -> ProtoOaClientPermissionScope
pub fn permission_scope(&self) -> ProtoOaClientPermissionScope
Returns the enum value of permission_scope, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_permission_scope(&mut self, value: ProtoOaClientPermissionScope)
pub fn set_permission_scope(&mut self, value: ProtoOaClientPermissionScope)
Sets permission_scope to the provided enum value.