pub struct ProtoOaGetDynamicLeverageByIdReq {
pub payload_type: Option<i32>,
pub ctid_trader_account_id: i64,
pub leverage_id: i64,
}Expand description
- Request for getting a dynamic leverage entity referenced in ProtoOASymbol.leverageId.
Fields
payload_type: Option<i32>ctid_trader_account_id: i64Unique identifier of the trader’s account. Used to match responses to trader’s accounts.
leverage_id: i64Implementations
Sourceimpl ProtoOaGetDynamicLeverageByIdReq
impl ProtoOaGetDynamicLeverageByIdReq
Sourcepub fn payload_type(&self) -> ProtoOaPayloadType
pub fn payload_type(&self) -> ProtoOaPayloadType
Returns the enum value of payload_type, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_payload_type(&mut self, value: ProtoOaPayloadType)
pub fn set_payload_type(&mut self, value: ProtoOaPayloadType)
Sets payload_type to the provided enum value.