pub struct ProtoOaGetPositionUnrealizedPnLRes {
pub payload_type: Option<i32>,
pub ctid_trader_account_id: i64,
pub position_unrealized_pn_l: Vec<ProtoOaPositionUnrealizedPnL>,
pub money_digits: u32,
}Expand description
- Response to ProtoOAGetPositionUnrealizedPnLReq request.
Fields
payload_type: Option<i32>ctid_trader_account_id: i64The unique identifier of the trader’s account in cTrader platform.
position_unrealized_pn_l: Vec<ProtoOaPositionUnrealizedPnL>Information about trader’s positions’ unrealized PnLs.
money_digits: u32Specifies the exponent of various monetary values. E.g., moneyDigits = 8 should be interpreted as the value multiplied by 10^8 with the ‘real’ value equal to 10053099944 / 10^8 = 100.53099944. Affects positionUnrealizedPnL.grossUnrealizedPnL, positionUnrealizedPnL.netUnrealizedPnL.
Implementations
Sourceimpl ProtoOaGetPositionUnrealizedPnLRes
impl ProtoOaGetPositionUnrealizedPnLRes
Sourcepub fn payload_type(&self) -> ProtoOaPayloadType
pub fn payload_type(&self) -> ProtoOaPayloadType
Returns the enum value of payload_type, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_payload_type(&mut self, value: ProtoOaPayloadType)
pub fn set_payload_type(&mut self, value: ProtoOaPayloadType)
Sets payload_type to the provided enum value.