pub struct ProtoOaGetTickDataReq {
pub payload_type: Option<i32>,
pub ctid_trader_account_id: i64,
pub symbol_id: i64,
pub type: i32,
pub from_timestamp: Option<i64>,
pub to_timestamp: Option<i64>,
}Expand description
- Request for getting historical tick data for the symbol.
Fields
payload_type: Option<i32>ctid_trader_account_id: i64Unique identifier of the trader’s account. Used to match responses to trader’s accounts.
symbol_id: i64Unique identifier of the Symbol in cTrader platform.
type: i32Bid/Ask (1/2).
from_timestamp: Option<i64>The Unix time in milliseconds of starting the search. Must be bigger or equal to zero (1st Jan 1970).
to_timestamp: Option<i64>The Unix time in milliseconds of finishing the search. <= 2147483646000 (19th Jan 2038).
Implementations
Sourceimpl ProtoOaGetTickDataReq
impl ProtoOaGetTickDataReq
Sourcepub fn payload_type(&self) -> ProtoOaPayloadType
pub fn payload_type(&self) -> ProtoOaPayloadType
Returns the enum value of payload_type, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_payload_type(&mut self, value: ProtoOaPayloadType)
pub fn set_payload_type(&mut self, value: ProtoOaPayloadType)
Sets payload_type to the provided enum value.
Sourcepub fn type(&self) -> ProtoOaQuoteType
pub fn type(&self) -> ProtoOaQuoteType
Returns the enum value of type, or the default if the field is set to an invalid enum value.
Sourcepub fn set_type(&mut self, value: ProtoOaQuoteType)
pub fn set_type(&mut self, value: ProtoOaQuoteType)
Sets type to the provided enum value.
Sourcepub fn from_timestamp(&self) -> i64
pub fn from_timestamp(&self) -> i64
Returns the value of from_timestamp, or the default value if from_timestamp is unset.
Sourcepub fn to_timestamp(&self) -> i64
pub fn to_timestamp(&self) -> i64
Returns the value of to_timestamp, or the default value if to_timestamp is unset.