pub struct ProtoOaGetTickDataRes {
pub payload_type: Option<i32>,
pub ctid_trader_account_id: i64,
pub tick_data: Vec<ProtoOaTickData>,
pub has_more: bool,
}Expand description
- Response to the ProtoOAGetTickDataReq request.
Fields
payload_type: Option<i32>ctid_trader_account_id: i64Unique identifier of the trader’s account. Used to match responses to trader’s accounts.
tick_data: Vec<ProtoOaTickData>The list of ticks is in chronological order (newest first). The first tick contains Unix time in milliseconds while all subsequent ticks have the time difference in milliseconds between the previous and the current one.
has_more: boolIf TRUE then the number of records by filter is larger than chunkSize, the response contains the number of records that is equal to chunkSize.
Implementations
Sourceimpl ProtoOaGetTickDataRes
impl ProtoOaGetTickDataRes
Sourcepub fn payload_type(&self) -> ProtoOaPayloadType
pub fn payload_type(&self) -> ProtoOaPayloadType
Returns the enum value of payload_type, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_payload_type(&mut self, value: ProtoOaPayloadType)
pub fn set_payload_type(&mut self, value: ProtoOaPayloadType)
Sets payload_type to the provided enum value.