pub struct ProtoOaGetTrendbarsReq {
pub payload_type: Option<i32>,
pub ctid_trader_account_id: i64,
pub from_timestamp: Option<i64>,
pub to_timestamp: Option<i64>,
pub period: i32,
pub symbol_id: i64,
pub count: Option<u32>,
}Expand description
- Request for getting historical trend bars for the symbol.
Fields
payload_type: Option<i32>ctid_trader_account_id: i64Unique identifier of the trader’s account. Used to match responses to trader’s accounts.
from_timestamp: Option<i64>The Unix time in milliseconds from which the search starts. Must be bigger or equal to zero (1st Jan 1970).
to_timestamp: Option<i64>The Unix time in milliseconds of finishing the search. Smaller or equal to 2147483646000 (19th Jan 2038).
period: i32Specifies period of trend bar series (e.g. M1, M10, etc.).
symbol_id: i64Unique identifier of the Symbol in cTrader platform.
count: Option<u32>Limit number of trend bars in response back from toTimestamp.
Implementations
Sourceimpl ProtoOaGetTrendbarsReq
impl ProtoOaGetTrendbarsReq
Sourcepub fn payload_type(&self) -> ProtoOaPayloadType
pub fn payload_type(&self) -> ProtoOaPayloadType
Returns the enum value of payload_type, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_payload_type(&mut self, value: ProtoOaPayloadType)
pub fn set_payload_type(&mut self, value: ProtoOaPayloadType)
Sets payload_type to the provided enum value.
Sourcepub fn from_timestamp(&self) -> i64
pub fn from_timestamp(&self) -> i64
Returns the value of from_timestamp, or the default value if from_timestamp is unset.
Sourcepub fn to_timestamp(&self) -> i64
pub fn to_timestamp(&self) -> i64
Returns the value of to_timestamp, or the default value if to_timestamp is unset.
Sourcepub fn period(&self) -> ProtoOaTrendbarPeriod
pub fn period(&self) -> ProtoOaTrendbarPeriod
Returns the enum value of period, or the default if the field is set to an invalid enum value.
Sourcepub fn set_period(&mut self, value: ProtoOaTrendbarPeriod)
pub fn set_period(&mut self, value: ProtoOaTrendbarPeriod)
Sets period to the provided enum value.