ProtoOaGetTrendbarsRes

Struct ProtoOaGetTrendbarsRes 

pub struct ProtoOaGetTrendbarsRes {
    pub payload_type: Option<i32>,
    pub ctid_trader_account_id: i64,
    pub period: i32,
    pub timestamp: Option<i64>,
    pub trendbar: Vec<ProtoOaTrendbar>,
    pub symbol_id: Option<i64>,
    pub has_more: Option<bool>,
}
  • Response to the ProtoOAGetTrendbarsReq request.

Fields

payload_type: Option<i32>ctid_trader_account_id: i64

Unique identifier of the trader’s account. Used to match responses to trader’s accounts.

period: i32

Specifies period of trend bar series (e.g. M1, M10, etc.).

timestamp: Option<i64>
👎Deprecated

Simply don’t use this field, as your original request already contains toTimestamp.

trendbar: Vec<ProtoOaTrendbar>

The list of trend bars.

symbol_id: Option<i64>

Unique identifier of the Symbol in cTrader platform.

has_more: Option<bool>

If TRUE then the number of records by filter is larger than chunkSize, the response contains the number of records that is equal to chunkSize.

Implementations

Source

impl ProtoOaGetTrendbarsRes

pub fn payload_type(&self) -> ProtoOaPayloadType

Returns the enum value of payload_type, or the default if the field is unset or set to an invalid enum value.

pub fn set_payload_type(&mut self, value: ProtoOaPayloadType)

Sets payload_type to the provided enum value.

pub fn period(&self) -> ProtoOaTrendbarPeriod

Returns the enum value of period, or the default if the field is set to an invalid enum value.

pub fn set_period(&mut self, value: ProtoOaTrendbarPeriod)

Sets period to the provided enum value.

pub fn timestamp(&self) -> i64

Returns the value of timestamp, or the default value if timestamp is unset.

pub fn symbol_id(&self) -> i64

Returns the value of symbol_id, or the default value if symbol_id is unset.

pub fn has_more(&self) -> bool

Returns the value of has_more, or the default value if has_more is unset.