pub struct ProtoOaLightSymbol {
pub symbol_id: i64,
pub symbol_name: Option<String>,
pub enabled: Option<bool>,
pub base_asset_id: Option<i64>,
pub quote_asset_id: Option<i64>,
pub symbol_category_id: Option<i64>,
pub description: Option<String>,
pub sorting_number: Option<f64>,
}Expand description
- Lightweight symbol entity.
Fields
symbol_id: i64The unique identifier of the symbol in specific server environment within cTrader platform. Different brokers might have different IDs.
symbol_name: Option<String>Name of the symbol (e.g. EUR/USD).
enabled: Option<bool>If TRUE then symbol is visible for traders.
base_asset_id: Option<i64>Base asset.
quote_asset_id: Option<i64>Quote asset.
symbol_category_id: Option<i64>Id of the symbol category used for symbols grouping.
description: Option<String>sorting_number: Option<f64>The number used for sorting Symbols in the UI (lowest number should appear at the top).
Implementations
Sourceimpl ProtoOaLightSymbol
impl ProtoOaLightSymbol
Sourcepub fn symbol_name(&self) -> &str
pub fn symbol_name(&self) -> &str
Returns the value of symbol_name, or the default value if symbol_name is unset.
Sourcepub fn enabled(&self) -> bool
pub fn enabled(&self) -> bool
Returns the value of enabled, or the default value if enabled is unset.
Sourcepub fn base_asset_id(&self) -> i64
pub fn base_asset_id(&self) -> i64
Returns the value of base_asset_id, or the default value if base_asset_id is unset.
Sourcepub fn quote_asset_id(&self) -> i64
pub fn quote_asset_id(&self) -> i64
Returns the value of quote_asset_id, or the default value if quote_asset_id is unset.
Sourcepub fn symbol_category_id(&self) -> i64
pub fn symbol_category_id(&self) -> i64
Returns the value of symbol_category_id, or the default value if symbol_category_id is unset.
Sourcepub fn description(&self) -> &str
pub fn description(&self) -> &str
Returns the value of description, or the default value if description is unset.
Sourcepub fn sorting_number(&self) -> f64
pub fn sorting_number(&self) -> f64
Returns the value of sorting_number, or the default value if sorting_number is unset.