pub struct ProtoOaMarginCall {
pub margin_call_type: i32,
pub margin_level_threshold: f64,
pub utc_last_update_timestamp: Option<i64>,
}Expand description
- Margin call entity, specifies threshold for exact margin call type. Only 3 instances of margin calls are supported, identified by marginCallType. See ProtoOANotificationType for details.
Fields
margin_call_type: i32Type of margin call. All margin calls are similar, only difference is in marginLevelThreshold.
margin_level_threshold: f64Margin level threshold for margin call.
utc_last_update_timestamp: Option<i64>The Unix time in milliseconds of the last update of the margin call.
Implementations
Sourceimpl ProtoOaMarginCall
impl ProtoOaMarginCall
Sourcepub fn margin_call_type(&self) -> ProtoOaNotificationType
pub fn margin_call_type(&self) -> ProtoOaNotificationType
Returns the enum value of margin_call_type, or the default if the field is set to an invalid enum value.
Sourcepub fn set_margin_call_type(&mut self, value: ProtoOaNotificationType)
pub fn set_margin_call_type(&mut self, value: ProtoOaNotificationType)
Sets margin_call_type to the provided enum value.
Sourcepub fn utc_last_update_timestamp(&self) -> i64
pub fn utc_last_update_timestamp(&self) -> i64
Returns the value of utc_last_update_timestamp, or the default value if utc_last_update_timestamp is unset.