pub struct ProtoOaMarginCallListRes {
pub payload_type: Option<i32>,
pub margin_call: Vec<ProtoOaMarginCall>,
}Expand description
- Response with a list of existing user Margin Calls, usually contains 3 items.
Fields
payload_type: Option<i32>margin_call: Vec<ProtoOaMarginCall>Implementations
Sourceimpl ProtoOaMarginCallListRes
impl ProtoOaMarginCallListRes
Sourcepub fn payload_type(&self) -> ProtoOaPayloadType
pub fn payload_type(&self) -> ProtoOaPayloadType
Returns the enum value of payload_type, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_payload_type(&mut self, value: ProtoOaPayloadType)
pub fn set_payload_type(&mut self, value: ProtoOaPayloadType)
Sets payload_type to the provided enum value.