pub struct ProtoOaMarginCallUpdateEvent {
pub payload_type: Option<i32>,
pub ctid_trader_account_id: i64,
pub margin_call: ProtoOaMarginCall,
}Expand description
- Event that is sent when a Margin Call threshold configuration is updated.
Fields
payload_type: Option<i32>ctid_trader_account_id: i64margin_call: ProtoOaMarginCallImplementations
Sourceimpl ProtoOaMarginCallUpdateEvent
impl ProtoOaMarginCallUpdateEvent
Sourcepub fn payload_type(&self) -> ProtoOaPayloadType
pub fn payload_type(&self) -> ProtoOaPayloadType
Returns the enum value of payload_type, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_payload_type(&mut self, value: ProtoOaPayloadType)
pub fn set_payload_type(&mut self, value: ProtoOaPayloadType)
Sets payload_type to the provided enum value.