pub struct ProtoOaMarginChangedEvent {
pub payload_type: Option<i32>,
pub ctid_trader_account_id: i64,
pub position_id: u64,
pub used_margin: u64,
pub money_digits: Option<u32>,
}Expand description
- Event that is sent when the margin allocated to a specific position is changed.
Fields
payload_type: Option<i32>ctid_trader_account_id: i64Unique identifier of the trader’s account. Used to match responses to trader’s accounts.
position_id: u64The unique ID of the position.
used_margin: u64The new value of the margin used.
money_digits: Option<u32>Specifies the exponent of the monetary values. E.g. moneyDigits = 8 must be interpret as business value multiplied by 10^8, then real balance would be 10053099944 / 10^8 = 100.53099944. Affects usedMargin.
Implementations
Sourceimpl ProtoOaMarginChangedEvent
impl ProtoOaMarginChangedEvent
Sourcepub fn payload_type(&self) -> ProtoOaPayloadType
pub fn payload_type(&self) -> ProtoOaPayloadType
Returns the enum value of payload_type, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_payload_type(&mut self, value: ProtoOaPayloadType)
pub fn set_payload_type(&mut self, value: ProtoOaPayloadType)
Sets payload_type to the provided enum value.
Sourcepub fn money_digits(&self) -> u32
pub fn money_digits(&self) -> u32
Returns the value of money_digits, or the default value if money_digits is unset.