pub struct ProtoOaOrderErrorEvent {
pub payload_type: Option<i32>,
pub ctid_trader_account_id: i64,
pub error_code: String,
pub order_id: Option<i64>,
pub position_id: Option<i64>,
pub description: Option<String>,
}Expand description
- Event that is sent when errors occur during the order requests.
Fields
payload_type: Option<i32>ctid_trader_account_id: i64Unique identifier of the trader’s account. Used to match responses to trader’s accounts.
error_code: StringThe name of the ProtoErrorCode or the other custom ErrorCodes (e.g. ProtoCHErrorCode).
order_id: Option<i64>The unique ID of the order.
position_id: Option<i64>The unique ID of the position.
description: Option<String>The error description.
Implementations
Sourceimpl ProtoOaOrderErrorEvent
impl ProtoOaOrderErrorEvent
Sourcepub fn payload_type(&self) -> ProtoOaPayloadType
pub fn payload_type(&self) -> ProtoOaPayloadType
Returns the enum value of payload_type, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_payload_type(&mut self, value: ProtoOaPayloadType)
pub fn set_payload_type(&mut self, value: ProtoOaPayloadType)
Sets payload_type to the provided enum value.
Sourcepub fn order_id(&self) -> i64
pub fn order_id(&self) -> i64
Returns the value of order_id, or the default value if order_id is unset.
Sourcepub fn position_id(&self) -> i64
pub fn position_id(&self) -> i64
Returns the value of position_id, or the default value if position_id is unset.
Sourcepub fn description(&self) -> &str
pub fn description(&self) -> &str
Returns the value of description, or the default value if description is unset.