pub struct ProtoOaPositionUnrealizedPnL {
pub position_id: i64,
pub gross_unrealized_pn_l: i64,
pub net_unrealized_pn_l: i64,
}Fields
position_id: i64The position ID.
gross_unrealized_pn_l: i64The gross unrealized PnL of the position denoted in the account deposit currency.
net_unrealized_pn_l: i64The net unrealized PnL of the position denoted in the account deposit currency. It does not include potential closing commission.