pub struct ProtoOaReconcileReq {
pub payload_type: Option<i32>,
pub ctid_trader_account_id: i64,
pub return_protection_orders: Option<bool>,
}Expand description
- Request for getting Trader’s current open positions and pending orders data.
Fields
payload_type: Option<i32>ctid_trader_account_id: i64Unique identifier of the trader’s account. Used to match responses to trader’s accounts.
return_protection_orders: Option<bool>If TRUE, then current protection orders are returned separately, otherwise you can use position.stopLoss and position.takeProfit fields.
Implementations
Sourceimpl ProtoOaReconcileReq
impl ProtoOaReconcileReq
Sourcepub fn payload_type(&self) -> ProtoOaPayloadType
pub fn payload_type(&self) -> ProtoOaPayloadType
Returns the enum value of payload_type, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_payload_type(&mut self, value: ProtoOaPayloadType)
pub fn set_payload_type(&mut self, value: ProtoOaPayloadType)
Sets payload_type to the provided enum value.
Sourcepub fn return_protection_orders(&self) -> bool
pub fn return_protection_orders(&self) -> bool
Returns the value of return_protection_orders, or the default value if return_protection_orders is unset.