pub struct ProtoOaSubscribeSpotsRes {
pub payload_type: Option<i32>,
pub ctid_trader_account_id: i64,
}Expand description
- Response to the ProtoOASubscribeSpotsReq request. Reflects that your request to subscribe for symbol has been added to queue. You’ll receive technical ProtoOASpotEvent with current price shortly after this response.
Fields
payload_type: Option<i32>ctid_trader_account_id: i64Unique identifier of the trader’s account. Used to match responses to trader’s accounts.
Implementations
Sourceimpl ProtoOaSubscribeSpotsRes
impl ProtoOaSubscribeSpotsRes
Sourcepub fn payload_type(&self) -> ProtoOaPayloadType
pub fn payload_type(&self) -> ProtoOaPayloadType
Returns the enum value of payload_type, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_payload_type(&mut self, value: ProtoOaPayloadType)
pub fn set_payload_type(&mut self, value: ProtoOaPayloadType)
Sets payload_type to the provided enum value.