pub struct ProtoOaSymbolsForConversionReq {
pub payload_type: Option<i32>,
pub ctid_trader_account_id: i64,
pub first_asset_id: i64,
pub last_asset_id: i64,
}Expand description
- Request for getting a conversion chain between two assets that consists of several symbols. Use when no direct quote is available.
Fields
payload_type: Option<i32>ctid_trader_account_id: i64Unique identifier of the trader’s account. Used to match responses to trader’s accounts.
first_asset_id: i64The ID of the firs asset in the conversation chain. e.g.: for EUR/USD the firstAssetId is EUR ID and lastAssetId is USD ID.
last_asset_id: i64The ID of the last asset in the conversation chain. e.g.: for EUR/USD the firstAssetId is EUR ID and lastAssetId is USD ID.
Implementations
Sourceimpl ProtoOaSymbolsForConversionReq
impl ProtoOaSymbolsForConversionReq
Sourcepub fn payload_type(&self) -> ProtoOaPayloadType
pub fn payload_type(&self) -> ProtoOaPayloadType
Returns the enum value of payload_type, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_payload_type(&mut self, value: ProtoOaPayloadType)
pub fn set_payload_type(&mut self, value: ProtoOaPayloadType)
Sets payload_type to the provided enum value.