pub struct ProtoOaSymbolsListReq {
pub payload_type: Option<i32>,
pub ctid_trader_account_id: i64,
pub include_archived_symbols: Option<bool>,
}Expand description
- Request for a list of symbols available for a trading account. Symbol entries are returned with the limited set of fields.
Fields
payload_type: Option<i32>ctid_trader_account_id: i64Unique identifier of the trader’s account. Used to match responses to trader’s accounts.
include_archived_symbols: Option<bool>Whether to include old archived symbols into response.
Implementations
Sourceimpl ProtoOaSymbolsListReq
impl ProtoOaSymbolsListReq
Sourcepub fn payload_type(&self) -> ProtoOaPayloadType
pub fn payload_type(&self) -> ProtoOaPayloadType
Returns the enum value of payload_type, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_payload_type(&mut self, value: ProtoOaPayloadType)
pub fn set_payload_type(&mut self, value: ProtoOaPayloadType)
Sets payload_type to the provided enum value.
Sourcepub fn include_archived_symbols(&self) -> bool
pub fn include_archived_symbols(&self) -> bool
Returns the value of include_archived_symbols, or the default value if include_archived_symbols is unset.