pub struct ProtoOaTraderUpdatedEvent {
pub payload_type: Option<i32>,
pub ctid_trader_account_id: i64,
pub trader: ProtoOaTrader,
}Expand description
- Event that is sent when a Trader is updated on Server side.
Fields
payload_type: Option<i32>ctid_trader_account_id: i64Unique identifier of the trader’s account. Used to match responses to trader’s accounts.
trader: ProtoOaTraderThe Trader account information.
Implementations
Sourceimpl ProtoOaTraderUpdatedEvent
impl ProtoOaTraderUpdatedEvent
Sourcepub fn payload_type(&self) -> ProtoOaPayloadType
pub fn payload_type(&self) -> ProtoOaPayloadType
Returns the enum value of payload_type, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_payload_type(&mut self, value: ProtoOaPayloadType)
pub fn set_payload_type(&mut self, value: ProtoOaPayloadType)
Sets payload_type to the provided enum value.