pub struct ProtoOaTrailingSlChangedEvent {
pub payload_type: Option<i32>,
pub ctid_trader_account_id: i64,
pub position_id: i64,
pub order_id: i64,
pub stop_price: f64,
pub utc_last_update_timestamp: i64,
}Expand description
- Event that is sent when the level of the Trailing Stop Loss is changed due to the price level changes.
Fields
payload_type: Option<i32>ctid_trader_account_id: i64Unique identifier of the trader’s account. Used to match responses to trader’s accounts.
position_id: i64The unique ID of the position.
order_id: i64The unique ID of the order.
stop_price: f64New value of the Stop Loss price.
utc_last_update_timestamp: i64The Unix time in milliseconds when the Stop Loss was updated.
Implementations
Sourceimpl ProtoOaTrailingSlChangedEvent
impl ProtoOaTrailingSlChangedEvent
Sourcepub fn payload_type(&self) -> ProtoOaPayloadType
pub fn payload_type(&self) -> ProtoOaPayloadType
Returns the enum value of payload_type, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_payload_type(&mut self, value: ProtoOaPayloadType)
pub fn set_payload_type(&mut self, value: ProtoOaPayloadType)
Sets payload_type to the provided enum value.