pub struct ProtoOaUnsubscribeLiveTrendbarReq {
pub payload_type: Option<i32>,
pub ctid_trader_account_id: i64,
pub period: i32,
pub symbol_id: i64,
}Expand description
- Request for unsubscribing from the live trend bars.
Fields
payload_type: Option<i32>ctid_trader_account_id: i64Unique identifier of the trader’s account. Used to match responses to trader’s accounts.
period: i32Specifies period of trend bar series (e.g. M1, M10, etc.).
symbol_id: i64Unique identifier of the Symbol in cTrader platform.
Implementations
Sourceimpl ProtoOaUnsubscribeLiveTrendbarReq
impl ProtoOaUnsubscribeLiveTrendbarReq
Sourcepub fn payload_type(&self) -> ProtoOaPayloadType
pub fn payload_type(&self) -> ProtoOaPayloadType
Returns the enum value of payload_type, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_payload_type(&mut self, value: ProtoOaPayloadType)
pub fn set_payload_type(&mut self, value: ProtoOaPayloadType)
Sets payload_type to the provided enum value.
Sourcepub fn period(&self) -> ProtoOaTrendbarPeriod
pub fn period(&self) -> ProtoOaTrendbarPeriod
Returns the enum value of period, or the default if the field is set to an invalid enum value.
Sourcepub fn set_period(&mut self, value: ProtoOaTrendbarPeriod)
pub fn set_period(&mut self, value: ProtoOaTrendbarPeriod)
Sets period to the provided enum value.