pub struct ProtoOaUnsubscribeSpotsReq {
pub payload_type: Option<i32>,
pub ctid_trader_account_id: i64,
pub symbol_id: Vec<i64>,
}Expand description
- Request for unsubscribing from the spot events of the specified symbol. Request to stop receiving ProtoOASpotEvents related to particular symbols. Unsubscription is useful to minimize traffic, especially during high volatility events.
Fields
payload_type: Option<i32>ctid_trader_account_id: i64Unique identifier of the trader’s account. Used to match responses to trader’s accounts.
symbol_id: Vec<i64>Unique identifier of the Symbol in cTrader platform.
Implementations
Sourceimpl ProtoOaUnsubscribeSpotsReq
impl ProtoOaUnsubscribeSpotsReq
Sourcepub fn payload_type(&self) -> ProtoOaPayloadType
pub fn payload_type(&self) -> ProtoOaPayloadType
Returns the enum value of payload_type, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_payload_type(&mut self, value: ProtoOaPayloadType)
pub fn set_payload_type(&mut self, value: ProtoOaPayloadType)
Sets payload_type to the provided enum value.