pub struct ProtoOaVersionReq {
pub payload_type: Option<i32>,
}Expand description
- Request for getting the proxy version. Can be used to check the current version of the Open API scheme.
Fields
payload_type: Option<i32>Implementations
Sourceimpl ProtoOaVersionReq
impl ProtoOaVersionReq
Sourcepub fn payload_type(&self) -> ProtoOaPayloadType
pub fn payload_type(&self) -> ProtoOaPayloadType
Returns the enum value of payload_type, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_payload_type(&mut self, value: ProtoOaPayloadType)
pub fn set_payload_type(&mut self, value: ProtoOaPayloadType)
Sets payload_type to the provided enum value.