#[repr(i32)]pub enum ProtoOaChangeBalanceType {
Show 35 variants
BalanceDeposit = 0,
BalanceWithdraw = 1,
BalanceDepositStrategyCommissionInner = 3,
BalanceWithdrawStrategyCommissionInner = 4,
BalanceDepositIbCommissions = 5,
BalanceWithdrawIbSharedPercentage = 6,
BalanceDepositIbSharedPercentageFromSubIb = 7,
BalanceDepositIbSharedPercentageFromBroker = 8,
BalanceDepositRebate = 9,
BalanceWithdrawRebate = 10,
BalanceDepositStrategyCommissionOuter = 11,
BalanceWithdrawStrategyCommissionOuter = 12,
BalanceWithdrawBonusCompensation = 13,
BalanceWithdrawIbSharedPercentageToBroker = 14,
BalanceDepositDividends = 15,
BalanceWithdrawDividends = 16,
BalanceWithdrawGslCharge = 17,
BalanceWithdrawRollover = 18,
BalanceDepositNonwithdrawableBonus = 19,
BalanceWithdrawNonwithdrawableBonus = 20,
BalanceDepositSwap = 21,
BalanceWithdrawSwap = 22,
BalanceDepositManagementFee = 27,
BalanceWithdrawManagementFee = 28,
BalanceDepositPerformanceFee = 29,
BalanceWithdrawForSubaccount = 30,
BalanceDepositToSubaccount = 31,
BalanceWithdrawFromSubaccount = 32,
BalanceDepositFromSubaccount = 33,
BalanceWithdrawCopyFee = 34,
BalanceWithdrawInactivityFee = 35,
BalanceDepositTransfer = 36,
BalanceWithdrawTransfer = 37,
BalanceDepositConvertedBonus = 38,
BalanceDepositNegativeBalanceProtection = 39,
}Expand description
- Balance operation entity. Covers all cash movement operations related to account, trading, IB operations, mirroring, etc.
Variants
BalanceDeposit = 0
Cash deposit.
BalanceWithdraw = 1
Cash withdrawal.
BalanceDepositStrategyCommissionInner = 3
Received mirroring commission.
BalanceWithdrawStrategyCommissionInner = 4
Paid mirroring commission.
BalanceDepositIbCommissions = 5
For IB account. Commissions paid by trader.
For IB account. Withdrawal of commissions shared with broker.
For IB account. Commissions paid by sub-ibs.
For IB account. Commissions paid by broker.
BalanceDepositRebate = 9
Deposit rebate for trading volume for period.
BalanceWithdrawRebate = 10
Withdrawal of rebate.
BalanceDepositStrategyCommissionOuter = 11
Mirroring commission.
BalanceWithdrawStrategyCommissionOuter = 12
Mirroring commission.
BalanceWithdrawBonusCompensation = 13
For IB account. Share commission with the Broker.
IB commissions.
BalanceDepositDividends = 15
Deposit dividends payments.
BalanceWithdrawDividends = 16
Negative dividend charge for short position.
BalanceWithdrawGslCharge = 17
Charge for guaranteedStopLoss.
BalanceWithdrawRollover = 18
Charge of rollover fee for Shariah compliant accounts.
BalanceDepositNonwithdrawableBonus = 19
Broker’s operation to deposit bonus.
BalanceWithdrawNonwithdrawableBonus = 20
Broker’s operation to withdrawal bonus.
BalanceDepositSwap = 21
Deposits of negative SWAP.
BalanceWithdrawSwap = 22
SWAP charges.
BalanceDepositManagementFee = 27
Mirroring commission.
BalanceWithdrawManagementFee = 28
Mirroring commission. Deprecated since 7.1 in favor of BALANCE_WITHDRAW_COPY_FEE (34).
BalanceDepositPerformanceFee = 29
Mirroring commission.
BalanceWithdrawForSubaccount = 30
Withdraw for subaccount creation (cTrader Copy).
BalanceDepositToSubaccount = 31
Deposit to subaccount on creation (cTrader Copy).
BalanceWithdrawFromSubaccount = 32
Manual user’s withdraw from subaccount (cTrader Copy), to parent account.
BalanceDepositFromSubaccount = 33
Manual user’s deposit to subaccount (cTrader Copy), from parent account.
BalanceWithdrawCopyFee = 34
Withdrawal fees to Strategy Provider.
BalanceWithdrawInactivityFee = 35
Withdraw of inactivity fee from the balance.
BalanceDepositTransfer = 36
Deposit within the same server (from another account).
BalanceWithdrawTransfer = 37
Withdraw within the same server (to another account).
BalanceDepositConvertedBonus = 38
Bonus being converted from virtual bonus to real deposit.
BalanceDepositNegativeBalanceProtection = 39
Applies if negative balance protection is configured by broker, should make balance = 0.
Implementations
Sourceimpl ProtoOaChangeBalanceType
impl ProtoOaChangeBalanceType
Sourcepub fn is_valid(value: i32) -> bool
pub fn is_valid(value: i32) -> bool
Returns true if value is a variant of ProtoOaChangeBalanceType.
Sourcepub fn from_i32(value: i32) -> Option<ProtoOaChangeBalanceType>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<ProtoOaChangeBalanceType>
Use the TryFrom<i32> implementation instead
Converts an i32 to a ProtoOaChangeBalanceType, or None if value is not a valid variant.
Sourceimpl ProtoOaChangeBalanceType
impl ProtoOaChangeBalanceType
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.