#[repr(i32)]pub enum ProtoOaSymbolDistanceType {
SymbolDistanceInPoints = 1,
SymbolDistanceInPercentage = 2,
}Expand description
- Enum for specifying stop loss and take profit distances.
Variants
Implementations
Sourceimpl ProtoOaSymbolDistanceType
impl ProtoOaSymbolDistanceType
Sourcepub fn is_valid(value: i32) -> bool
pub fn is_valid(value: i32) -> bool
Returns true if value is a variant of ProtoOaSymbolDistanceType.
Sourcepub fn from_i32(value: i32) -> Option<ProtoOaSymbolDistanceType>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<ProtoOaSymbolDistanceType>
Use the TryFrom<i32> implementation instead
Converts an i32 to a ProtoOaSymbolDistanceType, or None if value is not a valid variant.
Sourceimpl ProtoOaSymbolDistanceType
impl ProtoOaSymbolDistanceType
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.