ProtoErrorRes

Struct ProtoErrorRes 

pub struct ProtoErrorRes {
    pub payload_type: Option<i32>,
    pub error_code: String,
    pub description: Option<String>,
    pub maintenance_end_timestamp: Option<u64>,
}
  • Error response that is sent from Open API proxy when error occurs.

Fields

payload_type: Option<i32>error_code: String

Contains name of ProtoErrorCode or other custom ErrorCodes (e.g. ProtoCHErrorCode).

description: Option<String>

Error description.

maintenance_end_timestamp: Option<u64>

The Unix time in milliseconds of the end of the maintenance.

Implementations

Source

impl ProtoErrorRes

pub fn payload_type(&self) -> ProtoPayloadType

Returns the enum value of payload_type, or the default if the field is unset or set to an invalid enum value.

pub fn set_payload_type(&mut self, value: ProtoPayloadType)

Sets payload_type to the provided enum value.

pub fn description(&self) -> &str

Returns the value of description, or the default value if description is unset.

pub fn maintenance_end_timestamp(&self) -> u64

Returns the value of maintenance_end_timestamp, or the default value if maintenance_end_timestamp is unset.