ProtoMessage

Struct ProtoMessage 

pub struct ProtoMessage {
    pub payload_type: u32,
    pub payload: Option<Vec<u8>>,
    pub client_msg_id: Option<String>,
}
  • Base message that is used for all messages that are sent to/from Open API proxy of cTrader platform.

Fields

payload_type: u32

Contains id of ProtoPayloadType or other custom PayloadTypes (e.g. ProtoOAPayloadType).

payload: Option<Vec<u8>>

Serialized protobuf message that corresponds to payloadType.

client_msg_id: Option<String>

Request message id, assigned by the client that will be returned in the response.

Implementations

Source

impl ProtoMessage

pub fn payload(&self) -> &[u8]

Returns the value of payload, or the default value if payload is unset.

pub fn client_msg_id(&self) -> &str

Returns the value of client_msg_id, or the default value if client_msg_id is unset.