ProtoOaArchivedSymbol

Struct ProtoOaArchivedSymbol 

pub struct ProtoOaArchivedSymbol {
    pub symbol_id: i64,
    pub name: String,
    pub utc_last_update_timestamp: i64,
    pub description: Option<String>,
}

Fields

symbol_id: i64

The unique identifier of the symbol in specific server environment within cTrader platform. Different brokers might have different IDs.

name: String

Name of the symbol (e.g. EUR/USD).

utc_last_update_timestamp: i64

The Unix time in milliseconds of the last update of the symbol.

description: Option<String>

Description of the symbol.

Implementations

Source

impl ProtoOaArchivedSymbol

pub fn description(&self) -> &str

Returns the value of description, or the default value if description is unset.