ProtoOaDepositWithdraw

Struct ProtoOaDepositWithdraw 

pub struct ProtoOaDepositWithdraw {
    pub operation_type: i32,
    pub balance_history_id: i64,
    pub balance: i64,
    pub delta: i64,
    pub change_balance_timestamp: i64,
    pub external_note: Option<String>,
    pub balance_version: Option<i64>,
    pub equity: Option<i64>,
    pub money_digits: Option<u32>,
}
  • Account deposit/withdrawal operation entity.

Fields

operation_type: i32

Type of the operation. Deposit/Withdrawal.

balance_history_id: i64

The unique ID of the deposit/withdrawal operation.

balance: i64

Account balance after the operation was executed.

delta: i64

Amount of deposit/withdrawal operation.

change_balance_timestamp: i64

The Unix time in milliseconds when deposit/withdrawal operation was executed.

external_note: Option<String>

Note added to operation. Visible to the trader.

balance_version: Option<i64>

Balance version used to identify the final balance. Increments each time when the trader’s account balance is changed.

equity: Option<i64>

Total account’s equity after balance operation was executed.

money_digits: Option<u32>

Specifies the exponent of the monetary values. E.g. moneyDigits = 8 must be interpret as business value multiplied by 10^8, then real balance would be 10053099944 / 10^8 = 100.53099944. Affects balance, delta, equity.

Implementations

Source

impl ProtoOaDepositWithdraw

pub fn operation_type(&self) -> ProtoOaChangeBalanceType

Returns the enum value of operation_type, or the default if the field is set to an invalid enum value.

pub fn set_operation_type(&mut self, value: ProtoOaChangeBalanceType)

Sets operation_type to the provided enum value.

pub fn external_note(&self) -> &str

Returns the value of external_note, or the default value if external_note is unset.

pub fn balance_version(&self) -> i64

Returns the value of balance_version, or the default value if balance_version is unset.

pub fn equity(&self) -> i64

Returns the value of equity, or the default value if equity is unset.

pub fn money_digits(&self) -> u32

Returns the value of money_digits, or the default value if money_digits is unset.