pub struct ProtoOaMarginCallUpdateRes {
pub payload_type: Option<i32>,
}Expand description
- If this response received, it means that margin call was successfully updated.
Fields
payload_type: Option<i32>Implementations
Sourceimpl ProtoOaMarginCallUpdateRes
impl ProtoOaMarginCallUpdateRes
Sourcepub fn payload_type(&self) -> ProtoOaPayloadType
pub fn payload_type(&self) -> ProtoOaPayloadType
Returns the enum value of payload_type, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_payload_type(&mut self, value: ProtoOaPayloadType)
pub fn set_payload_type(&mut self, value: ProtoOaPayloadType)
Sets payload_type to the provided enum value.