ProtoOaSpotEvent

Struct ProtoOaSpotEvent 

pub struct ProtoOaSpotEvent {
    pub payload_type: Option<i32>,
    pub ctid_trader_account_id: i64,
    pub symbol_id: i64,
    pub bid: Option<u64>,
    pub ask: Option<u64>,
    pub trendbar: Vec<ProtoOaTrendbar>,
    pub session_close: Option<u64>,
    pub timestamp: Option<i64>,
}
  • Event that is sent when a new spot event is generated on the server side. Requires subscription on the spot events, see ProtoOASubscribeSpotsReq. First event, received after subscription will contain latest spot prices even if market is closed.

Fields

payload_type: Option<i32>ctid_trader_account_id: i64

Unique identifier of the trader’s account. Used to match responses to trader’s accounts.

symbol_id: i64

Unique identifier of the Symbol in cTrader platform.

bid: Option<u64>

Bid price. Specified in 1/100000 of unit of a price. (e.g. 123000 in protocol means 1.23, 53423782 means 534.23782)

ask: Option<u64>

Ask price. Specified in 1/100000 of unit of a price. (e.g. 123000 in protocol means 1.23, 53423782 means 534.23782)

trendbar: Vec<ProtoOaTrendbar>

Returns live trend bar. Requires subscription on the trend bars.

session_close: Option<u64>

Last session close. Specified in 1/100000 of unit of a price. (e.g. 123000 in protocol means 1.23, 53423782 means 534.23782)

timestamp: Option<i64>

The Unix time for spot.

Implementations

Source

impl ProtoOaSpotEvent

pub fn payload_type(&self) -> ProtoOaPayloadType

Returns the enum value of payload_type, or the default if the field is unset or set to an invalid enum value.

pub fn set_payload_type(&mut self, value: ProtoOaPayloadType)

Sets payload_type to the provided enum value.

pub fn bid(&self) -> u64

Returns the value of bid, or the default value if bid is unset.

pub fn ask(&self) -> u64

Returns the value of ask, or the default value if ask is unset.

pub fn session_close(&self) -> u64

Returns the value of session_close, or the default value if session_close is unset.

pub fn timestamp(&self) -> i64

Returns the value of timestamp, or the default value if timestamp is unset.