ProtoOaSubscribeSpotsReq

Struct ProtoOaSubscribeSpotsReq 

pub struct ProtoOaSubscribeSpotsReq {
    pub payload_type: Option<i32>,
    pub ctid_trader_account_id: i64,
    pub symbol_id: Vec<i64>,
    pub subscribe_to_spot_timestamp: Option<bool>,
}
  • Request for subscribing on spot events of the specified symbol. After successful subscription you’ll receive technical ProtoOASpotEvent with latest price, after which you’ll start receiving updates on prices via consequent ProtoOASpotEvents.

Fields

payload_type: Option<i32>ctid_trader_account_id: i64

Unique identifier of the trader’s account. Used to match responses to trader’s accounts.

symbol_id: Vec<i64>

Unique identifier of the Symbol in cTrader platform.

subscribe_to_spot_timestamp: Option<bool>

If TRUE you will also receive the timestamp in ProtoOASpotEvent.

Implementations

Source

impl ProtoOaSubscribeSpotsReq

pub fn payload_type(&self) -> ProtoOaPayloadType

Returns the enum value of payload_type, or the default if the field is unset or set to an invalid enum value.

pub fn set_payload_type(&mut self, value: ProtoOaPayloadType)

Sets payload_type to the provided enum value.

pub fn subscribe_to_spot_timestamp(&self) -> bool

Returns the value of subscribe_to_spot_timestamp, or the default value if subscribe_to_spot_timestamp is unset.