ProtoOaTradeData

Struct ProtoOaTradeData 

pub struct ProtoOaTradeData {
    pub symbol_id: i64,
    pub volume: i64,
    pub trade_side: i32,
    pub open_timestamp: Option<i64>,
    pub label: Option<String>,
    pub guaranteed_stop_loss: Option<bool>,
    pub comment: Option<String>,
    pub measurement_units: Option<String>,
    pub close_timestamp: Option<u64>,
}
  • Position/order trading details entity.

Fields

symbol_id: i64

The unique identifier of the symbol in specific server environment within cTrader platform. Different brokers might have different IDs.

volume: i64

Volume in cents (e.g. 1000 in protocol means 10.00 units).

trade_side: i32

Buy, Sell.

open_timestamp: Option<i64>

The Unix time in milliseconds when position was opened or order was created.

label: Option<String>

Text label specified during order request.

guaranteed_stop_loss: Option<bool>

If TRUE then position/order stop loss is guaranteedStopLoss.

comment: Option<String>

User-specified comment.

measurement_units: Option<String>

Specifies the units in which the Symbol is denominated.

close_timestamp: Option<u64>

The Unix time in milliseconds when a Position was closed

Implementations

Source

impl ProtoOaTradeData

pub fn trade_side(&self) -> ProtoOaTradeSide

Returns the enum value of trade_side, or the default if the field is set to an invalid enum value.

pub fn set_trade_side(&mut self, value: ProtoOaTradeSide)

Sets trade_side to the provided enum value.

pub fn open_timestamp(&self) -> i64

Returns the value of open_timestamp, or the default value if open_timestamp is unset.

pub fn label(&self) -> &str

Returns the value of label, or the default value if label is unset.

pub fn guaranteed_stop_loss(&self) -> bool

Returns the value of guaranteed_stop_loss, or the default value if guaranteed_stop_loss is unset.

pub fn comment(&self) -> &str

Returns the value of comment, or the default value if comment is unset.

pub fn measurement_units(&self) -> &str

Returns the value of measurement_units, or the default value if measurement_units is unset.

pub fn close_timestamp(&self) -> u64

Returns the value of close_timestamp, or the default value if close_timestamp is unset.