pub struct ProtoOaDealListByPositionIdReq {
pub payload_type: Option<i32>,
pub ctid_trader_account_id: i64,
pub position_id: i64,
pub from_timestamp: Option<i64>,
pub to_timestamp: Option<i64>,
}Expand description
- Request for retrieving the deals related to a position.
Fields
payload_type: Option<i32>ctid_trader_account_id: i64Unique identifier of the trader’s account. Used to match responses to trader’s accounts.
position_id: i64The unique ID of the position.
from_timestamp: Option<i64>The Unix time in milliseconds of starting the search. Must be bigger or equal to zero (1st Jan 1970).
to_timestamp: Option<i64>The Unix time in milliseconds of finishing the search. <= 2147483646000 (19th Jan 2038).
Implementations
Sourceimpl ProtoOaDealListByPositionIdReq
impl ProtoOaDealListByPositionIdReq
Sourcepub fn payload_type(&self) -> ProtoOaPayloadType
pub fn payload_type(&self) -> ProtoOaPayloadType
Returns the enum value of payload_type, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_payload_type(&mut self, value: ProtoOaPayloadType)
pub fn set_payload_type(&mut self, value: ProtoOaPayloadType)
Sets payload_type to the provided enum value.
Sourcepub fn from_timestamp(&self) -> i64
pub fn from_timestamp(&self) -> i64
Returns the value of from_timestamp, or the default value if from_timestamp is unset.
Sourcepub fn to_timestamp(&self) -> i64
pub fn to_timestamp(&self) -> i64
Returns the value of to_timestamp, or the default value if to_timestamp is unset.