pub struct ProtoOaOrderListRes {
pub payload_type: Option<i32>,
pub ctid_trader_account_id: i64,
pub order: Vec<ProtoOaOrder>,
pub has_more: bool,
}Expand description
- The response to the ProtoOAOrderListReq request.
Fields
payload_type: Option<i32>ctid_trader_account_id: i64Unique identifier of the trader’s account. Used to match responses to trader’s accounts.
order: Vec<ProtoOaOrder>The list of the orders.
has_more: boolIf TRUE then the number of records by filter is larger than chunkSize, the response contains the number of records that is equal to chunkSize.
Implementations
Sourceimpl ProtoOaOrderListRes
impl ProtoOaOrderListRes
Sourcepub fn payload_type(&self) -> ProtoOaPayloadType
pub fn payload_type(&self) -> ProtoOaPayloadType
Returns the enum value of payload_type, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_payload_type(&mut self, value: ProtoOaPayloadType)
pub fn set_payload_type(&mut self, value: ProtoOaPayloadType)
Sets payload_type to the provided enum value.