pub struct ProtoOaTrendbar {
pub volume: i64,
pub period: Option<i32>,
pub low: Option<i64>,
pub delta_open: Option<u64>,
pub delta_close: Option<u64>,
pub delta_high: Option<u64>,
pub utc_timestamp_in_minutes: Option<u32>,
}Expand description
- Historical Trendbar entity.
Fields
volume: i64Bar volume in ticks.
period: Option<i32>Bar period.
low: Option<i64>Low price of the bar.
delta_open: Option<u64>Delta between open and low price. open = low + deltaOpen.
delta_close: Option<u64>Delta between close and low price. close = low + deltaClose.
delta_high: Option<u64>Delta between high and low price. high = low + deltaHigh.
utc_timestamp_in_minutes: Option<u32>The Unix time in minutes of the bar, equal to the timestamp of the open tick.
Implementations
Sourceimpl ProtoOaTrendbar
impl ProtoOaTrendbar
Sourcepub fn period(&self) -> ProtoOaTrendbarPeriod
pub fn period(&self) -> ProtoOaTrendbarPeriod
Returns the enum value of period, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_period(&mut self, value: ProtoOaTrendbarPeriod)
pub fn set_period(&mut self, value: ProtoOaTrendbarPeriod)
Sets period to the provided enum value.
Sourcepub fn delta_open(&self) -> u64
pub fn delta_open(&self) -> u64
Returns the value of delta_open, or the default value if delta_open is unset.
Sourcepub fn delta_close(&self) -> u64
pub fn delta_close(&self) -> u64
Returns the value of delta_close, or the default value if delta_close is unset.
Sourcepub fn delta_high(&self) -> u64
pub fn delta_high(&self) -> u64
Returns the value of delta_high, or the default value if delta_high is unset.
Sourcepub fn utc_timestamp_in_minutes(&self) -> u32
pub fn utc_timestamp_in_minutes(&self) -> u32
Returns the value of utc_timestamp_in_minutes, or the default value if utc_timestamp_in_minutes is unset.