pub struct ProtoOaErrorRes {
pub payload_type: Option<i32>,
pub ctid_trader_account_id: Option<i64>,
pub error_code: String,
pub description: Option<String>,
pub maintenance_end_timestamp: Option<i64>,
pub retry_after: Option<u64>,
}Expand description
- Generic response when an ERROR occurred.
Fields
payload_type: Option<i32>ctid_trader_account_id: Option<i64>The unique identifier of the trader’s account in cTrader platform.
error_code: StringThe name of the ProtoErrorCode or the other custom ErrorCodes (e.g. ProtoCHErrorCode).
description: Option<String>The error description.
maintenance_end_timestamp: Option<i64>The Unix time in seconds when the current maintenance session will be ended.
retry_after: Option<u64>When you hit rate limit with errorCode=BLOCKED_PAYLOAD_TYPE, this field will contain amount of seconds until related payload type will be unlocked.
Implementations
Sourceimpl ProtoOaErrorRes
impl ProtoOaErrorRes
Sourcepub fn payload_type(&self) -> ProtoOaPayloadType
pub fn payload_type(&self) -> ProtoOaPayloadType
Returns the enum value of payload_type, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_payload_type(&mut self, value: ProtoOaPayloadType)
pub fn set_payload_type(&mut self, value: ProtoOaPayloadType)
Sets payload_type to the provided enum value.
Sourcepub fn ctid_trader_account_id(&self) -> i64
pub fn ctid_trader_account_id(&self) -> i64
Returns the value of ctid_trader_account_id, or the default value if ctid_trader_account_id is unset.
Sourcepub fn description(&self) -> &str
pub fn description(&self) -> &str
Returns the value of description, or the default value if description is unset.
Sourcepub fn maintenance_end_timestamp(&self) -> i64
pub fn maintenance_end_timestamp(&self) -> i64
Returns the value of maintenance_end_timestamp, or the default value if maintenance_end_timestamp is unset.
Sourcepub fn retry_after(&self) -> u64
pub fn retry_after(&self) -> u64
Returns the value of retry_after, or the default value if retry_after is unset.